#
# spec file for package postgis
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         pg_name  postgresql15%{nil}
%define         ext_name postgis
%{pg_version_from_name}
%define         main_version 3.5

Name:           %{pg_name}-%{ext_name}
Version:        3.5.0
Release:        2.1
Summary:        Geographic Information Systems Extensions to PostgreSQL
License:        GPL-2.0-or-later
Group:          Productivity/Databases/Servers
URL:            https://postgis.net/
Source0:        https://download.osgeo.org/postgis/source/%{ext_name}-%{version}.tar.gz
Source1:        https://postgis.net/stuff/%{ext_name}-%{version}.tar.gz.md5
BuildRequires:  %{pg_name}-llvmjit-devel
BuildRequires:  %{pg_name}-server-devel
BuildRequires:  cgal-devel
BuildRequires:  cunit-devel
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  gdal-devel >= 3.0
BuildRequires:  gtk2-devel
BuildRequires:  libgeos-devel >= 3.8.0
BuildRequires:  libjson-c-devel
BuildRequires:  libprotobuf-c-devel
BuildRequires:  proj-devel >= 6.1.0
# proj.db is required for ST_ functions and tests boo#1188129
BuildRequires:  proj
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  libxml2-devel
BuildRequires:  libxml2-tools
# building doc but would add 350 texlive packages
# BuildRequires:  dblatex
# BuildRequires:  ImageMagick
%ifarch %{ix86}
%define with_sfcgal 0
%else
%define with_sfcgal 1
BuildRequires:  sfcgal-devel >= 1.4.1
%endif
BuildRequires:  update-alternatives
%pg_server_requires
%if "%{pg_name}" == ""
Name:           %{ext_name}
ExclusiveArch:  do_not_build
%endif
# proj.db is required for ST_ functions and tests boo#1188129
Requires:       proj
Requires(post): update-alternatives
Requires(postun): update-alternatives
Conflicts:      postgis2
Provides:       postgis
Conflicts:      %{pg_name}-address_standardizer
Provides:       %{pg_name}-address_standardizer

%description
PostGIS is a spatial database extender for PostgreSQL object-relational
database. It adds support for geographic objects allowing location queries
to be run in SQL.

%package utils
Summary:        The utils for PostGIS
Group:          Productivity/Databases/Tools
Requires:       %{name} = %{version}
Requires:       perl-DBD-Pg
Provides:       postgis-utils
BuildArch:      noarch

%description utils
The postgis-utils package provides utilities for PostGIS.

%prep
%autosetup -p1 -n %{ext_name}-%{version}
echo "pg_version is %{pg_version}"

%build
# since 3.4.0, we need to move again those to pg_config_bindir for alternatives
%configure \
    --bindir=%{pg_config_bindir} \
    --datarootdir=%{pg_config_sharedir} \
    --datadir=%{pg_config_sharedir} \
    --with-protobuf \
    --with-raster \
    --with-topology \
    --with-gui \
    --with-json \
%if %{with_sfcgal}
    --with-sfcgal=%{_bindir}/sfcgal-config \
%endif
    --disable-rpath \
    --disable-gtktest \
    --with-interrupt-tests \
    --with-raster-dblwarning

%make_build soname="%{ext_name}-%{main_version}.so"

%install
install -d -m 755 %{buildroot}%{pg_config_bindir}
%make_install

# install manpages format them as our pg packages
install -d -m 755 %{buildroot}%{_mandir}/man1
# fix shebang and install utils
sed -i 's,^#!/usr/bin/env perl,#!/usr/bin/perl,g' utils/*.pl regress/*.pl %{buildroot}%{pg_config_bindir}/postgis_restore
rm utils/postgis_restore.pl
install -m 755 utils/*.pl %{buildroot}%{pg_config_bindir}
# remove .a and .la files
rm -f %{buildroot}/%{_libdir}/*.la
rm -f %{buildroot}/%{_libdir}/*.a

# Temporary fix we re-add the readme with doc macro
rm -fr %{buildroot}%{_docdir}/%{pg_name}

%fdupes -s %{buildroot}%{pg_config_sharedir}/extension
%fdupes -s %{buildroot}%{pg_config_sharedir}/contrib

find %{buildroot}/%{_mandir}/man1/ -type f -printf "mv %%p %%ppg%{pg_version}\n" | bash -x

%check
export LANG=en_US.UTF-8
export LC_ALL=en_US.UTF-8
export PGDATA=/home/abuild/postgis_tests/data
export PGHOST=/tmp
export PGPORT=5454
mkdir -p "${PGDATA}"
initdb --pgdata=${PGDATA} --auth=peer --auth-host=scram-sha-256 --auth-local=peer --encoding=UTF-8 --locale=en_US.UTF-8 --lc-message=en_US.UTF-8
pg_ctl -D "${PGDATA}" -l logfile -o "-p ${PGPORT} -k ${PGHOST} -B 1024" start
psql -d postgres -c "\dx"

# Manually try to create a databse and the 4 postgis extensions
# As extension are not installed system wide we use the old sql method
# Need access to $libdir/postgis not installed
#export LD_LIBRARY_PATH=%%{_libdir}:%%{buildroot}/%%{pg_libdir}
#export libdir=%%{buildroot}/%%{pg_libdir}
#psql -d postgres -c "create database %%{sname};"
#psql -d %%{sname} -f %%{buildroot}/%%{pg_share}/contrib/%%{sname}-%%{main_version}/postgis.sql
#psql -d %%{sname} -f %%{buildroot}/%%{pg_share}/contrib/%%{sname}-%%{main_version}/postgis_sfcgal.sql
#psql -d %%{sname} -f %%{buildroot}/%%{pg_share}/contrib/%%{sname}-%%{main_version}/postgis_raster.sql
#psql -d %%{sname} -f %%{buildroot}/%%{pg_share}/contrib/%%{sname}-%%{main_version}/postgis_topology.sql
#psql -d %%{sname} -c "\dx"
#psql -d %%{sname} -c "select postgis_full_version();"
# Don't fail test yet, we have a different result for mvt between Leap and TW
# Tests often failed one time, then retry.
make check || make check || :
pg_ctl -D "${PGDATA}" --mode="fast" stop

%postun
%{_datadir}/postgresql/install-alternatives %pg_version

%post
%{_datadir}/postgresql/install-alternatives %pg_version

%postun utils
%{_datadir}/postgresql/install-alternatives %pg_version

%post utils
%{_datadir}/postgresql/install-alternatives %pg_version

%files
%license COPYING LICENSE.TXT
%doc ChangeLog CODE_OF_CONDUCT.md CONTRIBUTING.md NEWS README.postgis SECURITY.md extensions/address_standardizer/README.address_standardizer
%{pg_config_pkglibdir}/*
%{_mandir}/man1/pgsql2shp.1pg%{pg_version}.gz
%{_mandir}/man1/pgtopo_export.1pg%{pg_version}.gz
%{_mandir}/man1/pgtopo_import.1pg%{pg_version}.gz
%{_mandir}/man1/postgis.1pg%{pg_version}.gz
%{_mandir}/man1/postgis_restore.1pg%{pg_version}.gz
%{_mandir}/man1/shp2pgsql.1pg%{pg_version}.gz
%{pg_config_bindir}/pgtopo_export
%{pg_config_bindir}/pgtopo_import
%{pg_config_bindir}/pgsql2shp
%{pg_config_bindir}/postgis
%{pg_config_bindir}/postgis_restore
%{pg_config_bindir}/raster2pgsql
%{pg_config_bindir}/shp2pgsql
%{pg_config_bindir}/shp2pgsql-gui
%dir %{pg_config_sharedir}/applications
%{pg_config_sharedir}/applications/shp2pgsql-gui.desktop
%dir %{pg_config_sharedir}/icons
%{pg_config_sharedir}/icons/*
%dir %{pg_config_sharedir}/contrib
%{pg_config_sharedir}/contrib/postgis*
%{pg_config_sharedir}/extension/postgis*
%{pg_config_sharedir}/extension/address_standardizer*

%files utils
%license COPYING LICENSE.TXT
%{pg_config_bindir}/create_extension_unpackage.pl
%{pg_config_bindir}/create_or_replace_to_create.pl
%{pg_config_bindir}/create_skip_signatures.pl
%{pg_config_bindir}/create_spatial_ref_sys_config_dump.pl
%{pg_config_bindir}/create_uninstall.pl
%{pg_config_bindir}/create_unpackaged.pl
%{pg_config_bindir}/create_upgrade.pl
%{pg_config_bindir}/profile_intersects.pl
%{pg_config_bindir}/read_scripts_version.pl
%{pg_config_bindir}/repo_revision.pl
%{pg_config_bindir}/test_estimation.pl
%{pg_config_bindir}/test_geography_estimation.pl
%{pg_config_bindir}/test_geography_joinestimation.pl
%{pg_config_bindir}/test_joinestimation.pl

%changelog
* Fri Feb 14 2025 Reinhard Max <max@suse.com>
- Drop support for postgresql12 which is EOL.
* Thu Sep 26 2024 Bruno Friedmann <bruno@ioda-net.ch>
- upgrade to version 3.5.0
  see full release note especially breaking changes
  https://git.osgeo.org/gitea/postgis/postgis/raw/tag/3.5.0/NEWS
- packaging:
  + set minimal geos version to 3.8
* Wed Sep 25 2024 Dirk Stoecker <opensuse@dstoecker.de>
- Enable postgres 17 builds
* Wed Sep 11 2024 Bruno Friedmann <bruno@ioda-net.ch>
- upgrade to version 3.4.3
  See full changelog since 3.4.2
  https://git.osgeo.org/gitea/postgis/postgis/raw/tag/3.4.3/NEWS
* Tue Apr  9 2024 Dirk Stoecker <opensuse@dstoecker.de>
- fix man file names installation problem of last update
* Tue Mar 12 2024 Bruno Friedmann <bruno@ioda-net.ch>
- upgrade to version 3.4.2
  See full changelog since 3.4.1
  https://git.osgeo.org/gitea/postgis/postgis/raw/tag/3.4.2/NEWS
- add support postgresql16, drop postgresql11 no more supported.
- adapt binaries distribution to place them in pg bin directory,
  with alternatives support
- refresh dependencies version
- drop patch-tests-results.patch
* Thu Feb 29 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Add BuildRequire proj-devel instead of legacy name libproj-devel.
* Thu Feb 29 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Wed Aug  2 2023 Bernhard Wiedemann <bwiedemann@suse.com>
- update to 3.3.4
  * Bug Fixes and Enhancements *
  - #5450, Fix macro expansion recursion on powerpc architectures.
    (Bas Couwenberg)
  - #5395, [postgis_topology] Allow unprivileged user dump
    of database with topology enabled
  - #5394, [postgis_topology] Improve robustness of finding
    distinct vertices in topology edges (Sandro Santilli)
  - #5403, [postgis_topology] Fix ValidateTopology(bbox) without
    topology in search_path (Sandro Santilli)
  - #5410, [postgis_raster] ST_Value bilinear resample,
    don't throw an error if Band has no NODATA value
    (Regina Obe)
  - #5385, Postgres malloc assertion fail when
    using pg_cancel_backend with ST_AsMVT
    (Regina Obe, Paul Ramsey)
  - #5452, Updated README.postgis for apt-based systems
    (Jelte Fennema)
  * Breaking Changes *
  - #5385, Take out interruptability of ST_AsMVT
    as it causes backend crash under intense conditions
    (Regina Obe, Paul Ramsey)
  PostGIS 3.3.3
  * Bug Fixes and Enhancements *
  - #5303, Don't try removing closed edges endpoint from
    RemoveUnusedPrimitives (Sandro Santilli)
  - #5289, Fix misleading message in RemoveUnusedPrimitives about
    doubly connected edges healing (Sandro Santilli)
  - #5298, Fix CopyTopology exception with hierarchical layers (Sandro Santilli)
  - #5299, Corrections to address_standardizer_data_us lex (Regina Obe)
  - #5332, Keep proj errors from percolating into PgSQL log (Paul Ramsey)
  This is a higher version upgrade, see
  https://git.osgeo.org/gitea/postgis/postgis/raw/tag/3.3.4/NEWS
  for the full log since 3.2 release.
* Wed Jul 26 2023 Dirk Stoecker <opensuse@dstoecker.de>
- update to 3.2.5: Bug Fixes
  - #5384, Fix crash in ST_AsGML when given id is longer than given prefix
    (Sandro Santilli)
  - #5380, Fix 2.5 upgrades with views using geography based ST_Distance
    (Sandro Santilli)
  - #5106, Fix segfault in ST_RemEdgeNewFace/ST_RemEdgeModFace
    when no edge side-faces are found (Sandro Santilli)
  - #5313, Fix memory access issue in ST_InterpolateRaster (Paul Ramsey)
  - #5338, Dump/Restore of raster table fails on
    enforce_coverage_tile_rast constraint (Regina Obe)
  - #5315, #5318, #5319, #5320, #5342 crashes on infinite coordinates
    (Regina Obe, Paul Ramsey)
  - #5344, Include topology id sequence state in dumps (Sandro Santilli)
  - #5288, ST_LineCrossingDirection multi-cross error (Paul Ramsey)
  - #5347, _ST_BestSRID crashes on ARM with infinite geometries (Regina Obe)
  - #5363, Make ST_ClusterDBScan interruptable (Paul Ramsey)
  - #5378, ST_Buffer(geography) drops SRID (Paul Ramsey)
  - #5331, [postgis_tiger_geocoder] reverse_geocode, prefer addressable ranges
    (Regina Obe, Locance)
* Fri Nov 25 2022 Bruno Friedmann <bruno@ioda-net.ch>
- Update to PostGIS 3.2.4 (boo#1205734)
  * [security] Add schema qual to upgrade util
  * [security] Check function ownership at extension packaging time
  * Fix ST_DumpPoints and ST_DumpSegments crash with empty polygon
  * Remove forced static linking on shp2pgsql, pgsql2shp, raster2pgsql
  * Fix crash on ST_SnapToGrid with empty multis
  * Fix error in topology import of self-intersecting rings
  * Fix 2.5d topology building regression
  * Handle load of dbase character fields with no width specified
  * Fix bad rasterization of linestring
- includes changes from PostGIS 3.2.3:
  * Parallelism safety fixes for to_jsonb, ST_AsGeoJSON, ST_AsGML
  * Guard against downgrades
  * Fix upgrades with CVE-2022-2625 PostgreSQL fix
  * Correctly read extent off multi-key GIST indexes
  * Reset proj error state after failed parse
  * Short circuit geodesic distance when inputs equal
  * Fix potential buffer overflow in long transaction locks
- Add postgresql15 to multibuild and remove postgresql10
* Wed Aug  3 2022 Bruno Friedmann <bruno@ioda-net.ch>
- Update to bugfix version 3.2.2
  - #5182, Fix loading topology.sql in new database
  - #4835, Occasional distance errors in polar area
  - #5124, GRANT USAGE on topology schema to PUBLIC
  - #5120, Fix not-null result from ST_EstimatedExtent against
    truncated tables with spatial index
  - #5115, Allow dropping topologies with pending constraints
  - #5105, Fix false invalidity report from ValidateTopology
  - #5039, postgis_tiger_geocoder: Support for TIGER 2021 (Regina Obe)
  - #5097, Ensure spatial index is used during topology population
    at the getClosestEdge step
  - #5091, Fix --without-protobuf builds
  - #5100, Don't use pg_atoi (removed in PG15)
  - #5114, Crash with long column names pgsql2shp
  - #5123, Support for PG15 (JSON funcs exposed)
  - #5125, Fix search path function
  - #5150, Change signature of AddToSearchPath
  - #5151, ST_SetPoint with empty geometries
  - #5152, Fix infinite loop with ST_Split
  - #5173, Crash creating flatgeobuf on row without geometry
  - #4541, ST_ConcaveHull returns a "geometrycollection" type
    instead of the expected "polygon"
  - #5154, raster ST_Value is undercosted
- Disable sfcgal for ix86 arch (sfcgal can't be build for those)
  Please try to uninstall sfcgal before doing extension upgrade.
* Tue Jun 28 2022 Marcus Rueckert <mrueckert@suse.de>
- no longer pull clang-devel and llvm-devel directory the correct
  version will be pulled via %%{pg_name}-llvmjit-devel
* Tue Mar 15 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fix Name in spec when %%{pgname} is not defined
* Thu Feb 24 2022 Bruno Friedmann <bruno@ioda-net.ch>
- Update to bugfix release version 3.2.1
  - #5033, #5035, allow upgrades in presence of views using deprecated
    functions
  - #5046, Fix upgrades in absence of old library
  - #5063, Fix ST_Srid(TopoGeometry) against a set
  - #3056, spurious notice on ST_StartPoint(empty)
  - #5041, postgis_tiger_geocoder: loader_generate_script
    generates script with invalid syntax
  - #5076, stop install when pgaudit is active
  - #5069, search_path vulnerabilty during install/upgrade
  - #5090, #5091 configure --with-protobuf-lib / --with-protobufdir
    , --without-protobuf broken
- Packaging
  - Add upstream -md5 source1
* Tue Jan  4 2022 Bruno Friedmann <bruno@ioda-net.ch>
- Update to version 3.2.0 "Olivier Courtin Edition"
  Please consult carefully the changelog
  https://git.osgeo.org/gitea/postgis/postgis/raw/tag/3.2.0/NEWS
- Packaging
  + Renew spec file with new postgresql macros
  + Retry test if failed as they success often on 2nd pass
  + Add postgresql14 to multibuild
  + Spec cleaner with copyright date update
  + Remove postgis-rpmlintrc due to last unused filter
    E: unused-rpmlintrc-filter "W: shared-lib-calls-exit *"
  + Added provides conflit address_standardizer
* Wed Sep 15 2021 Bruno Friedmann <bruno@ioda-net.ch>
- Update to version 3.1.4 bugfix release
  - #4782, Have postgis_restore.pl use backup postgis schema by
    default
  - #4854, Fix type of TopoGeometry receiving different-type
    TopoGeometry components
  - #4918, Fix rare crash in st_minpossiblevalue
  - #4941, Fix loose mbr in topology.face on update
  - #4949, Swapped coordinates for N/E planar systems
  - GI617, Fix typo in setting of INVMINDIST
  - #4326, Fix CircularPolygon area calculation
  - #4917, Fix crasher with '-' regclass
  - #4919, Rare crash in selectivity calculation
  - #4926, Preserve SRID on unions of empty geometry
  - #4910, Allow repeated points in GML input poslists
  - #4958, TIGER2020 fix faces and add Tabblock20
  - #4959, Drop Colorado state files also drops national county tables
  - #4916, #4770, #4724, #4916, Crashes in aggregate functions
  - #4982, Problem when calling the buffer function from MobilityDB
- Packaging:
  - Fix build llvm by adding BuildRequires
* Tue Jul 13 2021 Bruno Friedmann <bruno@ioda-net.ch>
- Update to version 3.1.3 bugfix release
  - #4929, Fix missing error from GetRingEdges when invoked with
    unexistent topology or edge
  - #4927, Fix PostgreSQL 14 compile FuncnameGetCandidates changes
- Update to version 3.1.2 bugfix release
  - #4871 TopoGeometry::geometry cast returns NULL for empty
    TopoGeometry objects
  - #4826 postgis_tiger_geocoder Better answers when no zip
    is provided
  - #4817 handle more complex compound coordinate dystems
  - #4842 Only do axis flips on CRS that have a "Lat" as the
    first column
  - Support recent Proj versions that have removed pj_get_release
  - #4835 Adjust tolerance for geodetic calculations
  - #4840 Improper conversion of negative geographic azimuth to
    positive
  - #4853 DBSCAN cluster not formed when recordset length equal
    to minPoints
  - #4863 Update bboxes after scale/affine coordinate changes
  - #4876 Fix raster issues related to PostgreSQL 14 tablefunc
    changes
  - #4877 mingw64 PostGIS / PostgreSQL 14 compile
  - #4838 Update to support Tiger 2020
  - #4890 Change Proj cache lifetime to last as long as connection
  - #4845 Add Pg14 build support
- Packaging
  - Force Require for proj so proj.db is present and all ST_
    functions will work boo#1188129
  - Activate tests for pg10+
  - Add patch-tests-results.patch to fix results on openSUSE
  - Remove libname package and description as not used
  - Remove references and build for obsolete versions
  - Suppress build for now obsolete postgresql96
* Mon Mar 22 2021 Bruno Friedmann <bruno@ioda-net.ch>
- Remove specific flag --without-library-minor-version as it
  activate also the minor version.
* Thu Mar 18 2021 Bruno Friedmann <bruno@ioda-net.ch>
- Packaging add install-updates for utils package
* Tue Mar 16 2021 Bruno Friedmann <bruno@ioda-net.ch>
- Update to version 3.1.1 bugfix release
  + #4814, Crash passing collection with only empty components
    to ST_MakeValid
  + #4818, Make the VSICURL synthetic driver work as documented
  + #4825, Unstable results from ST_MakeValid
  + #4823, Avoid listing the same geometry in different collections
- Packaging
  + Commented but prepared buildrequires cunit for tests
  + Add explicit --without-library-minor-version .so is now only
    .3 and no more .3.1
* Mon Feb  1 2021 Bruno Friedmann <bruno@ioda-net.ch>
- Packaging:
  + split llvm-jit data to its own package
  + Remove obsolete %%if block (42.3)
  + Normalize define and macro (pointcloud,pgRouting)
  + Review build targets (while keeping 15.1 a bit longer)
* Tue Jan 12 2021 Bruno Friedmann <bruno@ioda-net.ch>
- Update to version 3.1.0 release
  https://git.osgeo.org/gitea/postgis/postgis/raw/tag/3.1.0/NEWS
  + Breaking changes
  - #4737, Bump minimum protobuf-c requirement to 1.1.0
    The configure step will now fail if the requirement isn't
    met or explicitly disabled (--without-protobuf)
  - #4258, Separated postgis_sfcgal from postgis
    into its own lib file and extension (Regina Obe)
  - #4577, Drop support for PostgreSQL 9.5
  - #4601, ST_TileEnvelope signature changed.
  - #3057, ST_Force3D, ST_Force3DZ, ST_Force3DM and ST_Force4D
    signatures changed.
  + Think to upgrade your DB with new instructions
    SELECT postgis_extensions_upgrade();
- Packaging:
  + double quote each var in %%if section (fix build failure)
  + Add gcc-c++ to enable --with-wagyu
  + Remove support for pg95 (9.6 and 10 will be soon be dropped
    due to icu68) think to upgrade your main PostgreSQL server
  + Integrate Leap 15.3 (pg12 and pg13)
* Thu Jan  7 2021 Bruno Friedmann <bruno@ioda-net.ch>
- Update to bugfix release 3.0.3
  - #4742 tiger geocoder reverted to 2018 version on tiger upgrade
  - #4757, Handle line collapse due to snap-to-existing node
  - #4758, Improve topology noding robustness
  - #4719, Fail fast when srids don't match ST_Intersection(geometry,raster)
    Also schema qualify calls in function.
  - #4739, Ensure all functions using postgis_oid initialize the internal cache
  - #4767, #4768, #4771, #4772, Fix segfault when parsing invalid WKB
  - #4769, Fix segfault in st_addband
  - #4748, Fix incorrect axis swapping in polar stereographic
  - #4727, Fix bug in geocentrix box computation
  - #4790, Fix ST_3dintersects calculations with identical vertices
- Packaging: update copyright year
* Sat Oct 31 2020 Bruno Friedmann <bruno@ioda-net.ch>
- Activate postgresql13 where it's possible to have it
* Mon Oct 12 2020 Bruno Friedmann <bruno@ioda-net.ch>
- Update to bugfix release version 3.0.2
  - Remove useless duplicated call in ST_ChangeEdgeGeom
  - #4709, Fix crash in adding edge to corrupted topology
  - Handle non-closed edge rings by human readable error
  - #4706, Fix crash in ST_ChangeEdgeGeom on corrupted topology
  - #4652, Fix several memory related bugs in ST_GeomFromGML
  - #4661,4129, Fix access to spatial_ref_sys with a non default schema
  - #4670, ST_AddPoint: Fix bug when a positive position is requested
  - #4702, Legacy ST_Locate_Between_Measures is wrong
  - #4699, crash on null input to ST_Union(raster, otherarg)
  - #4716, Fix several issues with pkg-config in the configure script
  - #4691, Fix segfault during gist index creation with empty geometries
  - #4541, ST_ConcaveHull returns a "geometrycollection"
    type instead of the expected "polygon"
  - #4640, Update raster docs to explain why ST_Transform using
    alignment is important.
    Update raster FAQ
* Thu Jun 18 2020 Bruno Friedmann <bruno@ioda-net.ch>
- Change and simplify the macro testing do_not_build to allow
  builds for PostgreSQL 11 & 12 on Leap 15.2
* Sat Mar 14 2020 Bruno Friedmann <bruno@ioda-net.ch>
- Update to major version 3.0.1
  + You will have to backup and restore your database if the
    extension upgrade doesn't work. Be carefull
  + Raster is now separated from main extension
  + All changes are listed at
    https://git.osgeo.org/gitea/postgis/postgis/raw/tag/3.0.1/NEWS
    and
    https://git.osgeo.org/gitea/postgis/postgis/raw/tag/3.0.0/NEWS
- Update to previous minor to 2.5.4
- Packaging
  + Adjust copyright
  + Remove postgresql94 support
  + -lib and  -devel package are no longer built as their contents
  liblwgeom are no longer publicly exposed by upstream
  + Adjust postgresql10, 11, 12 version to according target
  + Use --without-phony-revision (new 3.0.1) to avoid constant
    rebuild
  + Use --without-wagyu as wagyu lib is not packaged for openSUSE
* Thu Feb 13 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Enable protobuf-c support
* Sat Feb  1 2020 Bruno Friedmann <bruno@ioda-net.ch>
- Add postgresql12 support after project config adaptation
* Sun Oct  6 2019 Bruno Friedmann <bruno@ioda-net.ch>
- Update to version 2.5.3
  * Bug fixes *
  - #4348, ST_AsMVTGeom (GEOS): Enforce validation at all times (Raúl Marín)
  - #4361, Fix postgis_type_name with (GEOMETRYM,3) (Matt Bretl)
  - #4326, Fix circular arc distance calculation (Paul Ramsey)
  - #4380, Simple TIN support to allow viz in QGIS (Paul Ramsey)
  - #4388, AddRasterConstraints: Ignore NULLs when generating constraints (Raúl Marín)
  - #4327, Avoid pfree'ing the result of getenv (Raúl Marín)
  - #4406, Throw on invalid characters when decoding geohash (Raúl Marín)
  - #4440, Internal type lookups fail over FDW (Paul Ramsey)
  - #4445, Fix bug in lwgeom_le (Raúl Marín)
  - #4466, Fix undefined behaviour in _postgis_gserialized_stats (Raúl Marín)
  - #4209, Handle NULL geometry values in pgsql2shp (Paul Ramsey)
  - #4419, Use protobuf version to enable/disable mvt/geobuf (Paul Ramsey)
  - #4437, Handle POINT EMPTY in shape loader/dumper (Paul Ramsey)
  - #4461, ST_AsTWKB doesn't always remove duplicate points (Nicklas Avén)
  - #4459, Fix ST_Subdivide crash on intermediate EMPTY (Darafei Praliaskouski)
  - #4470, ST_GeomFromGeoJSON crash on empty rings (Darafei Praliaskouski)
  - #4420, update path does not exists for address_standardizer extension (Regina Obe)
- Minimal cleanup of spec file
* Sat Mar 30 2019 Bruno Friedmann <bruno@ioda-net.ch>
- Update to version 2.5.2 (old 2.4.7) with proj6 support
  * Bug fixes *
  - #4231, Support for PostgreSQL 12dev (remove use of pg_constraint.consrc)
    (Regina Obe, Laurenz Albe)
  - #4247, Avoid undefined behaviour in next_float functions (Raúl Marín)
  - #4249, Fix undefined behaviour in raster intersection (Raúl Marín)
  - #4246, Fix undefined behaviour in ST_3DDistance (Raúl Marín)
  - #4244, Avoid unaligned memory access in BOX2D_out (Raúl Marín)
  - #4139, Make mixed-dimension ND index build tree correctly.
  WARNING: REINDEX your ND index on tables that have records with different M/Z
    dimensions for &&& operator to work predictably.
    (Darafei Praliaskouski, Arthur Lesuisse, Andrew Gierth, Raúl Marín)
  - #4262, Document MULTISURFACE compatibility of ST_LineToCurve (Steven Ottens)
  - #4267, Enable Proj 6 deprecated APIs (Darafei Praliaskouski, Raúl Marín)
  - #4276, ST_AsGeoJSON documentation refresh (Darafei Praliaskouski)￼
  - #4273, Tighter parsing of WKT (Paul Ramsey)
  - #4292, ST_AsMVT: parse JSON numeric values with decimals as doubles (Raúl Marín)
  - #4300, ST_AsMVTGeom: Always return the simplest geometry (Raúl Marín)
  - #4301, ST_Subdivide: fix endless loop on coordinates near coincident to bounds
    (Darafei Praliaskouski)
  - #4261, Use AccessShareLock in spatial_index_read_extent (Paul Ramsey)
  - #4289, ST_AsMVTGeom: Transform coordinates space before clipping (Raúl Marín)
  - #4275, Avoid passing a NULL pointer to GEOSisEmpty (Raúl Marín)
  - #4296, Use `server_version_num` instead of parsing `version()` (Raúl Marín)
  - #4290, More robust geography distance (Paul Ramsey)
  - #4283, Avoid final point duplicates for circle stroking (Paul Ramsey)
  - #4314, ST_ClipByBox2D: Do not throw when the geometry is invalid (Raúl Marín)
  - #4313, #4307, PostgreSQL 12 compatibility (Laurenz Albe, Raúl Marín)
  - #4290, Schema qualify geometry casts in raster functions (Regina Obe)
  - #4086, Constraint violation loading tiger_data (zcta5 geometry type) (Regina Obe)
- Packaging
  - Add support for postgresql11 in multibuild
  - Add server-devel
* Sun Nov 25 2018 Bruno Friedmann <bruno@ioda-net.ch>
- Add 42.3 as postgresql10 target since pg10 is available on
  42.3-update channel
* Mon Nov 19 2018 Guillaume GARDET <guillaume.gardet@opensuse.org>
-  Update to 2.5.1:
  * Bug fixes *
  - #4183, St_AsMVTGeom: Drop invalid geometries after simplification (Raúl Marín)
  - #4188, Avoid division by zero in kmeans (Raúl Marín)
  - #4189, Fix undefined behaviour in SADFWrite (Raúl Marín)
  - #4191, Fix undefined behaviour in ptarray_clone_deep (Raúl Marín)
  - #4020, Fix leftovers in topology upgrade from 2.1 (Sandro Santilli)
  - #4206, Fix support for PostgreSQL 12 dev branch (Laurenz Albe)
  - #4211, Fix ST_Subdivide for minimal exterior ring with minimal hole (Darafei
    Praliaskouski)
  - #3457, Fix raster envelope shortcut in ST_Clip (Sai-bot)
  - #4215, Use floating point compare in ST_DumpAsPolygons (Darafei Praliaskouski)
  - #4217, Fix ST_Subdivide crash on EMPTY in intermediate iterations (Darafei
    Praliaskouski)
  - #4223, ST_DistanceTree error for near parallel boxes (Paul Ramsey)
  - Schema qualify more functions for raster (Regina Obe)
  - #4216, Revert non-sliced box access (Paul Ramsey)
  - #2767, Documentation for AddRasterConstraint optional parameters (Sunveer Singh)
  - #4326, Allocate enough memory in gidx_to_string (Raúl Marín)
  - #4190, Avoid undefined behaviour in gserialized_estimate
* Thu Oct  4 2018 guillaume@opensuse.org
- Remove postgresql93 support
* Thu Oct  4 2018 guillaume@opensuse.org
- Update to new 2.5.0:
  WARNING: If compiling with PostgreSQL+JIT, LLVM >= 6 is required
  Supported PostgreSQL versions for this release are:
  PostgreSQL 9.4 - PostgreSQL 12 (in development)
  GEOS >= 3.5
  * New Features *
  - #1847, spgist 2d and 3d support for PG 11+
    (Esteban Zimányi and Arthur Lesuisse from Université Libre de Bruxelles (ULB),
    Darafei Praliaskouski)
  - #4056, ST_FilterByM (Nicklas Avén)
  - #4050, ST_ChaikinSmoothing (Nicklas Avén)
  - #3989, ST_Buffer single sided option (Stephen Knox)
  - #3876, ST_Angle function (Rémi Cura)
  - #3564, ST_LineInterpolatePoints (Dan Baston)
  - #3896, PostGIS_Extensions_Upgrade() (Regina Obe)
  - #3913, Upgrade when creating extension from unpackaged (Sandro Santilli)
  - #2256, _postgis_index_extent() for extent from index (Paul Ramsey)
  - #3176, Add ST_OrientedEnvelope (Dan Baston)
  - #4029, Add ST_QuantizeCoordinates (Dan Baston)
  - #4063, Optional false origin point for ST_Scale (Paul Ramsey)
  - #4082, Add ST_BandFileSize and ST_BandFileTimestamp,
    extend ST_BandMetadata (Even Rouault)
  - #2597, Add ST_Grayscale (Bborie Park)
  - #4007, Add ST_SetBandPath (Bborie Park)
  - #4008, Add ST_SetBandIndex (Bborie Park)
  * Breaking Changes *
  - #4054, ST_SimplifyVW changed from > tolerance to >= tolerance
  - #3885, version number removed from address_standardize lib file
    (Regina Obe)
  - #3893, raster support functions can only be loaded in the same schema
    with core PostGIS functions. (Sandro Santilli)
  - #4035, remove dummy pgis_abs type from aggregate/collect routines.
    (Paul Ramsey)
  - #4069, drop support for GEOS < 3.5 and PostgreSQL < 9.4 (Regina Obe)
  - #4082, ST_BandMetaData extended to include filesize, timestamp (Even Rouault)
  * Enhancements and Fixes*
  - Upgrade scripts from multiple old versions are now all symlinks
    to a single upgrade script (Sandro Santilli)
  - #3944, Update to EPSG register v9.2 (Even Rouault)
  - #3927, Parallel implementation of ST_AsMVT
  - #3925, Simplify geometry using map grid cell size before generating MVT
  - #3899, BTree sort order is now defined on collections of EMPTY and
    same-prefix geometries (Darafei Praliaskouski)
  - #3864, Performance improvement for sorting POINT geometries
    (Darafei Praliaskouski)
  - #3900, GCC warnings fixed, make -j is now working (Darafei Praliaskouski)
  - TopoGeo_addLinestring robustness improvements (Sandro Santilli)
    [#1855], #1946, #3718, #3838
  - #3234, Do not accept EMPTY points as topology nodes (Sandro Santilli)
  - #1014, Hashable geometry, allowing direct use in CTE signatures (Paul Ramsey)
  - #3097, Really allow MULTILINESTRING blades in ST_Split() (Paul Ramsey)
  - #3942, geojson: Do not include private header for json-c >= 0.13 (Björn Esser)
  - #3954, ST_GeometricMedian now supports point weights (Darafei Praliaskouski)
  - #3965, #3971, #3977, #4071 ST_ClusterKMeans rewritten: better initialization,
    faster convergence, K=2 even faster (Darafei Praliaskouski)
  - #3982, ST_AsEncodedPolyline supports LINESTRING EMPTY and MULTIPOINT EMPTY
    (Darafei Praliaskouski)
  - #3986, ST_AsText now has second argument to limit decimal digits
    (Marc Ducobu, Darafei Praliaskouski)
  - #4020, Casting from box3d to geometry now returns correctly connected
    PolyhedralSurface (Matthias Bay)
  - #2508, ST_OffsetCurve now works with collections (Darafei Praliaskouski)
  - #4006, ST_GeomFromGeoJSON support for json and jsonb as input
    (Paul Ramsey, Regina Obe)
  - #4038, ST_Subdivide now selects pivot for geometry split that reuses input
    vertices. (Darafei Praliaskouski)
  - #4025, #4032 Fixed precision issue in ST_ClosestPointOfApproach,
    ST_DistanceCPA, and ST_CPAWithin (Paul Ramsey, Darafei Praliaskouski)
  - #4076, Reduce use of GEOS in topology implementation (Björn Harrtell)
  - #4080, Add external raster band index to ST_BandMetaData
  - Add Raster Tips section to Documentation for information about
    Raster behavior (e.g. Out-DB performance, maximum open files)
  - #4084: Fixed wrong code-comment regarding front/back of BOX3D (Matthias Bay)
  - #4060, #4094, PostgreSQL JIT support (Raúl Marín, Laurenz Albe)
  - #3960, ST_Centroid now uses lwgeom_centroid (Darafei Praliaskouski)
  - #4027, Remove duplicated code in lwgeom_geos (Darafei Praliaskouski,
    Daniel Baston)
  - #4115, Fix a bug that created MVTs with incorrect property values under
    parallel plans (Raúl Marín).
  - #4120, ST_AsMVTGeom: Clip using tile coordinates (Raúl Marín).
  - #4132, ST_Intersection on Raster now works without throwing TopologyException
    (Vinícius A.B. Schmidt, Darafei Praliaskouski)
  - #4177, #4180 Support for PostgreSQL 12 dev branch (Laurenz Albe, Raúl Marín)
  - #4156, ST_ChaikinSmoothing: also smooth start/end point of
  polygon by default (Darafei Praliaskouski)
- Move 2.4.5 to previous version
- Remove no more needed patch:
  * ccb7b1.patch
* Thu Oct  4 2018 guillaume@opensuse.org
- Update to bugfix release PostGIS 2.4.5
  * Bug Fixes and Enchantments
  - #4031, Survive to big MaxError tolerances passed to ST_CurveToLine
    (Sandro Santilli)
  - #4058, Fix infinite loop in linearization of a big radius small arc
    (Sandro Santilli)
  - #4071, ST_ClusterKMeans crash on NULL/EMPTY fixed (Darafei Praliaskouski)
  - #4079, ensure St_AsMVTGeom outputs CW oriented polygons (Paul Ramsey)
  - #4070, use standard interruption error code on GEOS interruptions
    (Paul Ramsey)
  - #3980, delay freeing input until processing complete (lucasvr)
  - #4090, PG 11 support (Paul Ramsey, RaÃºl MarÃ­n)
  - #4077, Serialization failure for particular empty geometry cases (Paul Ramsey)
  - #3997, fix bug in lwgeom_median and avoid division by zero (RaÃºl MarÃ­n)
  - #4093, Inconsistent results from qsort callback (yugr)
  - #4081, Geography DWithin() issues for certain cases (Paul Ramsey)
  - #4105, Parallel build of tarball (Bas Couwenberg)
  - #4163, MVT: Fix resource leak when the first geometry is NULL (RaÃºl MarÃ­n)
* Mon Apr 16 2018 bruno@ioda-net.ch
- update to bugfix release PostGIS 2.4.4
  * Bug fixes *
  - #3055, [raster] ST_Clip() on a raster without band crashes the
  server (Regina Obe)
  - #3942, geojson: Do not include private header for json-c >= 0.13
    (Böjrn Esser)
  - #3952, ST_Transform fails in parallel mode (Paul Ramsey)
  - #3978, Fix KNN when upgrading from 2.1 or older (Sandro Santilli)
  - #4003, lwpoly_construct_circle: Avoid division by zero
  - #4004, Avoid memory exhaustion when building a btree index
    (Edmund Horner)
  - #4016, proj 5.0.0 support
  - #4017, lwgeom lexer memory corruption (Peter E)
  - #4020, Casting from box3d to geometry now returns correctly
    connected PolyhedralSurface (Matthias Bay)
  - #4025, #4032 Incorrect answers for temporally "almost
    overlapping" ranges (Paul Ramsey, Darafei Praliaskouski)
  - #4052, schema qualify several functions in geography
  (Regina Obe)
  - #4055, ST_ClusterIntersecting drops SRID (Daniel Baston)
  * Enhancements *
  - #3946, Compile support for PgSQL 11 (Paul Ramsey)
  - #3992, Use PKG_PROG_PKG_CONFIG macro from pkg.m4 to detect
    pkg-config (Bas Couwenberg)
  - #4044, Upgrade support for PgSQL 11 (Regina Obe)
- Don't apply ccb7b1.patch merged upstream for 2.4 but keep it for
  2.3
* Sun Feb 11 2018 bruno@ioda-net.ch
- update to bugfixes release PostGIS 2.4.3
  + Bug fixes *
  - #3713, Support encodings that happen to output a '\' character
  - #3827, Set configure default to not do interrupt testing,
    was causing false negatives for many people (Regina Obe)
    revised to be standards compliant in #3988 (Greg Troxel)
  - #3930, Minimum bounding circle issues on 32-bit platforms
  - #3965, ST_ClusterKMeans used to lose some clusters on
    initialization (Darafei Praliaskouski)
  - #3956, Brin opclass object does not upgrade properly
    (Sandro Santilli)
  - #3982, ST_AsEncodedPolyline supports LINESTRING EMPTY and
    MULTIPOINT EMPTY (Darafei Praliaskouski)
  - #3975, ST_Transform runs query on spatial_ref_sys without schema
    qualification. Was causing restore issues. (Paul Ramsey)
  + Enhancements
  - #3944, Update to EPSG register v9.2 (Even Rouault)
* Fri Jan 12 2018 bruno@ioda-net.ch
- Packaging : add ccb7b1.patch fixing upstream bug
  https://trac.osgeo.org/postgis/ticket/3942#ticket
  geojson: Do not include private header for json-c >= 0.13
* Fri Jan  5 2018 bruno@ioda-net.ch
- Packaging:
  + Move to _multibuild way including PostgreSQL version 10
  + Remove minimal PostgreSQL version
  + Remove build for 9.2 (unsupported upstream)
  + spec-cleaner minimal
  + Activate postgresql/install-alternative for suse_version > 1500
    This script in only available in TW and 15x
    This mean proper alternatives for binary is not handle for Leap
    42.3 and there's no easy way to have them packaged
- Update to 2.4.2 release
  - #3917, Fix zcta5 load
  - #3667, Fix for bug in geography ST_Segmentize
  - #3926, Add missing 2.2.6 and 2.3.4 upgrade paths (Muhammad Usama)
- Version 2.4.1
  + Bug fixes
  - #3864, Fix memory leaks in BTREE operators
  - #3869, Fix build with "gold" linker
  - #3845, Gracefully handle short-measure issue
  - #3871, Performance tweak for geometry cmp function
  - #3879, Division by zero in some arc cases
  - #3878, Single defn of signum in header
  - #3880, Undefined behaviour in TYPMOD_GET_SRID
  - #3875, Fix undefined behaviour in shift operation
  - #3864, Performance improvements for b-tree geometry sorts
  - #3874, lw_dist2d_pt_arc division by zero
  - #3882, undefined behaviour in zigzag with negative inputs
  - #3891, undefined behaviour in pointarray_to_encoded_polyline
  - #3895, throw error on malformed WKB input
  - #3886, fix rare missing boxes in geometry subdivision
  - #3907, Allocate enough space for all possible GBOX string outputs
  + Enhancements
  - #3815, Tiger 2017 data support and option to load zcta5
- Version 2.4.0
  + New Features
  - #3822, Have postgis_full_version() also show and check version of
    PostgreSQL the scripts were built against (Sandro Santilli)
  - #2411, curves support in ST_Reverse (Sandro Santilli)
  - #2951, ST_Centroid for geography (Danny GÃ¶tte)
  - #3788, Allow postgis_restore.pl to work on directory-style (-Fd)
    dumps (Roger Crew)
  - #3772, Direction agnostic ST_CurveToLine output
    (Sandro Santilli / KKGeo)
  - #2464, ST_CurveToLine with MaxError tolerance
    (Sandro Santilli / KKGeo)
  - #3599, Geobuf output support via ST_AsGeobuf (Björn Harrtell)
  - #3661, Mapbox vector tile output support via ST_AsMVT
    (Björn Harrtell / CartoDB)
  - #3689, Add orientation checking and forcing functions (Dan Baston)
  - #3753, Gist penalty speed improvements for 2D and ND points
    (Darafei Praliaskouski, Andrey Borodin)
  - #3677, ST_FrechetDistance (Shinichi Sugiyama)
  - Most aggregates (raster and geometry), and all stable/immutable
    (raster and geometry) marked as parallel safe
  - #2249, ST_MakeEmptyCoverage for raster (David Zwarg, ainomieli)
  - #3709, Allow signed distance for ST_Project (Darafei Praliaskouski)
  - #524, Covers support for polygon on polygon, line on line, point
    on line for geography (Danny Gtte)
  + Enhancements and Fixes
  - Many corrections to docs and several translations almost complete.
    Andreas Schild who provided many corrections to core docs.
    PostGIS Japanese translation team first to reach completion of
    translation.
  - Support for PostgreSQL 10
  - Preliminary support for PostgreSQL 11
  - #3645, Avoid loading logically deleted records from shapefiles
  - #3747, Add zip4 and address_alphanumeric as attributes
    to norm_addy tiger_geocoder type.
  - #3748, address_standardizer lookup tables update
    so pagc_normalize_address better standardizes abbreviations
  - #3647, better handling of noding in ST_Node using GEOSNode
    (Wouter Geraedts)
  - #3684, Update to EPSG register v9
    (Even Rouault)
  - #3830, Fix initialization of incompatible type (>=9.6)
    address_standardizer
  - #3662, Make shp2pgsql work in debug mode by sending debug to stderr
  - #3405, Fixed memory leak in lwgeom_to_points
  - #3832, Support wide integer fields as int8 in shp2pgsql
  - #3841, Deterministic sorting support for empty geometries in
    btree geography
  - #3844, Make = operator a strict equality test, and < > to rough
    "spatial sorting"
  - #3855, ST_AsTWKB memory and speed improvements
  + Breaking Changes
  - Dropped support for PostgreSQL 9.2.
  - #3810, GEOS 3.4.0 or above minimum required to compile
  - Most aggregates now marked as parallel safe,
    which means most aggs have to be dropped / recreated.
    If you have views that utilize PostGIS aggs,
    you'll need to drop before upgrade and recreate after upgrade
  - #3578, ST_NumInteriorRings(POLYGON EMPTY) now returns 0 instead
    of NULL
  - _ST_DumpPoints removed, was no longer needed after PostGIS 2.1.0
    when ST_DumpPoints got reimplemented in C
  - B-Tree index operators < = > changed to provide better spatial
    locality on sorting and have expected behavior on GROUP BY.
    If you have btree index for geometry or geography, you need to
    REINDEX it, or review if it was created by accident and needs to
    be replaced with GiST index.
    If your code relies on old left-to-right box compare ordering,
    update it to use << >> operators
- Update to main previous 2.3.5
  - #3667, Fix for bug in geography ST_Segmentize
  - #3926, Add missing 2.2.6 upgrade path
- Update to PostGIS 2.3.4
  - PostgreSQL 10 support
  - #3782, Memory leak in lwline_from_wkb_state (Even Rouault)
  - #3101, Fix buffer overflow in pgsql2shp (Sandro Santilli)
  - #3786, ptarray null and heap issues on is_closed
  - #3795, Solaris build issues due to missing isfinite define
    (Julian Schauder)
  - #3792, mark all 3D related including SFCGAL as parallel safe
  - #3800, shp2pgql-gui allow export of foreign tables, materialized
    views, and partitioned tables
  - #3806, Reverse geocoder missing suffix direction when present
  - #3698, loading census tabblock is broken
  - #3839, loader tests sometimes crash because of variables not
    initialized also reenable cunit loader tess to always run.
  - #3774, Trigonometric length for CompoundCurves
  - #3731, Crash on very small table of homogenous data
  - #2836, Receiving ERROR: ExteriorRing: geom is
    not a polygon with ST_ConcaveHull
  - #3781, Not-quite curved CurvePolygon rejected by ST_Contains
  - #3818, Triangles unclosed in M should be parseable
  - #3866, Rare crash generating TWKB with large coordinate values
  - #3869, Fix build with "gold" linker
  - #3845, Gracefully handle short-measure issue
  - #3879, Division by zero in some arc cases
  - #3878, Single defn of signum in header
  - #3880, Undefined behaviour in TYPMOD_GET_SRID
  - #3875, Fix undefined behaviour in shift operation
  - #3874, lw_dist2d_pt_arc division by zero
  - #3882, undefined behaviour in zigzag with negative inputs
  - #3891, undefined behaviour in pointarray_to_encoded_polyline
  - #3895, throw error on malformed WKB input
  - #3907, Allocate enough space for all possible GBOX string outputs
* Wed Jul 12 2017 bruno@ioda-net.ch
- Update to bugfix release 2.3.3
  * Bug Fixes :
  + Several improvement to documentation
  + Several improvement in regress test suite
  + NEWS, raster/rt_pg/rtpg_mapalgebra.c: Change ST_Clip from Error
    to Notice when ST_Clip can compute no band Closes #3730
  + postgis/lwgeom_btree.c, regress/operators.sql,
    regress/operators_expected: Fix lwgeom_cmp return code
    Closes #3777 once again
  + topology/postgis_topology.c: Fix compiler warnings about
    printf-like formats
  + NEWS, postgis/lwgeom_btree.c, regress/operators.sql,
    regress/operators_expected: Fix handling of EMPTY geometries in
    btree operator. Includes regress test. Closes #3777 for 2.3
  + NEWS, liblwgeom/lwout_x3d.c, regress/tickets.sql,
    regress/tickets_expected: ST_AsX3D handle empty geometries
    Closes #3704 for PostGIS 2.3.3
  + NEWS, loader/pgsql2shp-core.c, loader/pgsql2shp-core.h,
    regress/dumper/realtable_expected.dbf: Backport fixes for
    pgsql2shp for Boolean field length and quote escaping Includes
    tests for both. Closes #3682, Closes #3701
  + postgis/Makefile.in: Avoid ever-growing postgis extension
    upgrade scripts. Fixes #3775 for 2.3 branch
  + postgis/Makefile.in: Style only change: remove trailing blanks
  + NEWS, postgis/postgis.sql.in, raster/rt_pg/rtpostgis.sql.in:
    @ operator not schema qualified and ~ not schema qualified in
    some places apply patch with adjustments.
    Patch provided by Shane StClair (Axiom Data Science)
    Closes #3750 for PostGIS 2.3.3
  + NEWS, liblwgeom/lwgeom.c, regress/subdivide.sql,
    regress/subdivide_expected: ST_Subdivide loses subparts of
    inverted geometries patch from Darafei Praliaskouski (Komzpa)
    Closes #3744 for PostGIS 2.3 changed area regress to cast to
    numeric so doesn't return scientific notation on windows
  + NEWS, raster/loader/raster2pgsql.c: Get rid of logic that set
    out_srid to same as input srid and change to not try to
    transform when out_srid is unknown. Closes #3738 PostGIS 2.3
  + NEWS, liblwgeom/lwgeom_topo.c,
    topology/test/regress/topogeo_addlinestring.sql,
    topology/test/regress/topogeo_addlinestring_expected_newsnap,
    topology/test/regress/topogeo_addlinestring_expected_oldsnap:
    Fix azimuth computation for 2.5D edge ends.
  The change disreguard vertical movemements of the edge and
    computes azimuth of the first segment getting away from the
    node.
  Includes automated testcase
  Closes #3711
- Packaging: remove no more maintained 92 postgresql version
* Sun Mar  5 2017 bruno@ioda-net.ch
- Update to bugfix release 2.3.2
  * Bug Fixes
  + 3418, KNN recheck in 9.5+ fails with index returned tuples
    in wrong order
  + 3675, Relationship functions not using an index in some cases
  + 3680, PostGIS upgrade scripts missing GRANT for views
  + 3683, Unable to update postgis after postgres pg_upgrade
    going from < 9.5 to pg > 9.4
  + 3688, ST_AsLatLonText: round minutes
- Packaging :
  - Add support for postgresql96
  - Add Requires to postgresql[VER]
* Wed Dec  7 2016 bruno@ioda-net.ch
- Update to bugfix release 2.3.1
  * Bug Fixes
  + #1973, st_concavehull() returns sometimes empty geometry
    collection (gde)
  + #3501, add raster constraint max extent exceeds array size
    limit for large tables
  + #3643, PostGIS not building on latest OSX XCode
  + #3644, Deadlock on interrupt
  + #3650, Mark ST_Extent, ST_3DExtent and ST_Mem* agg functions
    as parallel safe so they can be parallelized
  + #3652, Crash on Collection(MultiCurve())
  + #3656, Fix upgrade of aggregates from 2.2 or lower version
  + #3659, Crash caused by raster GUC define after
    CREATE EXTENSION using wrong memory context. (manaeem)
  + #3665, Index corruption and memory leak in BRIN indexes
    (Julien Rouhaud of Dalibo)
  + #3667, geography ST_Segmentize bug (Hugo Mercier of Oslandia)
- Packaging removed upstream merged patches
  - upstream-3644-deadlock.diff
  - upstream-3653-crash-collection.diff
  - upstream-3656-fix-aggregates-upgrade.diff
  - upstream-3656-add-missing-checker.diff
  - upstream-geos35-error-message.diff
  - upstream-3659-raster-guc.diff
  - upstream-1973-st_concavehull-returns-empty-geo.diff
* Sun Nov  6 2016 bruno@ioda-net.ch
- Packaging Fixes :
  + Add shp2pgsql-gui to main package
  + Move all bin perl scripts to postgis-util package
  + Remove bogus alternatives calls: if postgis is uninstalled all
    postgresql alternatives were removed.
  + Add postgresql95 support
  + Review of dependencies minimal supported is now geos 3.5 and
    postgresql 9.2
  + Remove all "older versions", but still build with previous to
    help admins during upgrades.
  * ** ALTER EXTENSION xxx UPDATE to '2.3.0'; *** is mandatory
    after install on all gis database.
  + Critical patches from upstream (2.3.1)
  - upstream-3644-deadlock.diff
  - upstream-3653-crash-collection.diff
  - upstream-3656-fix-aggregates-upgrade.diff
  - upstream-3656-add-missing-checker.diff
  - upstream-geos35-error-message.diff
  - upstream-3659-raster-guc.diff
  - upstream-1973-st_concavehull-returns-empty-geo.diff
- liblwgeom soversion is now 0.0.0
- Update to new upstream major release 2.3.0
  * Important / Breaking Changes *
  - #3466, Casting from box3d to geometry now returns a 3D
    geometry (Julien Rouhaud of Dalibo)
  - #3604, pgcommon/Makefile.in orders CFLAGS incorrectly leading
    to wrong liblwgeom.h (Greg Troxel)
  - #3396, ST_EstimatedExtent, throw WARNING instead of ERROR
    (Regina Obe)
  * Deprecated signatures *
  - none
  * New Features *
  - Add support for custom TOC in postgis_restore.pl
    (Christoph Moench-Tegeder)
  - Add support for negative indexing in ST_PointN and ST_SetPoint
    (Rémi Cura)
  - Add parameters for geography ST_Buffer (Thomas Bonfort)
  - TopoGeom_addElement, TopoGeom_remElement (Sandro Santilli)
  - populate_topology_layer (Sandro Santilli)
  - #454,  ST_WrapX and lwgeom_wrapx (Sandro Santilli)
  - #1758, ST_Normalize (Sandro Santilli)
  - #2236, shp2pgsql -d now emits "DROP TABLE IF EXISTS"
  - #2259, ST_VoronoiPolygons and ST_VoronoiLines (Dan Baston)
  - #2841 and #2996, ST_MinimumBoundingRadius and new
    ST_MinimumBoundingCircle implementation using Welzl's algorithm
    (Dan Baston)
  - #2991, Enable ST_Transform to use PROJ.4 text (Mike Toews)
  - #3059, Allow passing per-dimension parameters in ST_Expand
    (Dan Baston)
  - #3339, ST_GeneratePoints (Paul Ramsey)
  - #3362, ST_ClusterDBSCAN (Dan Baston)
  - #3364, ST_GeometricMedian (Dan Baston)
  - #3391, Add table inheritance support in ST_EstimatedExtent
    (Alessandro Pasotti)
  - #3424, ST_MinimumClearance (Dan Baston)
  - #3428, ST_Points (Dan Baston)
  - #3465, ST_ClusterKMeans (Paul Ramsey)
  - #3469, ST_MakeLine with MULTIPOINTs (Paul Norman)
  - #3549, Support PgSQL 9.6 parallel query mode, as far as possible
    (Paul Ramsey, Regina Obe)
  - #3557, Geometry function costs based on query stats (Paul Norman)
  - #3591, Add support for BRIN indexes. PostgreSQL 9.4+ required.
    (Giuseppe Broccolo of 2nd Quadrant, Julien Rouhaud
    and Ronan Dunklau of Dalibo)
  - #3496, Make postgis non-relocateable for extension install,
    schema qualify calls in functions (Regina Obe)
    Should resolve once and for all for extensions #3494,
    [#3486], #3076
  - #3547, Update tiger geocoder to support TIGER 2016
    and to support both http and ftp.
  - #3613, Segmentize geography using equal length segments
    (Hugo Mercier of Oslandia)
  * Bug Fixes
  - #2841, ST_MinimumBoundingCircle not covering original
  * Performance Enhancements *
  - #75, Enhancement to PIP short circuit (Dan Baston)
  - #3383, Avoid deserializing small geometries during index
    operations (Dan Baston)
  - #3400, Minor optimization of PIP routines (Dan Baston)
  - Make adding a line to topology interruptible
    (Sandro Santilli)
  - Documentation updates from Mike Toews
* Sun Apr 24 2016 bruno@ioda-net.ch
- packaging
  * use %%fdupes
  * add rpmlintrc to shutup non sense messages
  * shp2pgsql-gui is now builded and place in the utils package
- liblwgeom soversion bump to 5.0.1
- Updated to bug fix release 2.2.2
  - #3463, Fix crash on face-collapsing edge change
  - #3422, Improve ST_Split robustness on standard precision double
    systems (arm64, ppc64el, s390c, powerpc, ...)
  - #3427, Update spatial_ref_sys to EPSG version 8.8
  - #3433, ST_ClusterIntersecting incorrect for MultiPoints
  - #3435, ST_AsX3D fix rendering of concave geometries
  - #3436, memory handling mistake in ptarray_clone_deep
  - #3437, ST_ClusterIntersecting incorrect for MultiPoints
  - #3461, ST_GeomFromKML crashes Postgres when there are
    innerBoundaryIs and no outerBoundaryIs
  - #3429, upgrading to 2.3 or from 2.1 can cause loop/hang on some
    platforms
  - #3460, ST_ClusterWithin 'Tolerance not defined' error after
  upgrade
  - #3490, Raster data restore issues, materialized views
    Scripts postgis_proc_set_search_path.sql,
  rtpostgis_proc_set_search_path.sql
    refer to
  http://postgis.net/docs/manual-2.2/RT_FAQ.html#faq_raster_data_not_restore
  - #3426, failing POINT EMPTY tests on fun architectures
* Tue Feb 23 2016 bruno@ioda-net.ch
- packaging :
  * Include previous and older up to 2.0 version to make extension update working
  * Add sfgal so extension sfcgal is available
  * Fix _smp_mflags to -j1 which is the upstream recommandation
  * Add address_standardizer extension and files
- Updated to 2.2.1
  * Bug Fixes *
  - #2232, avoid accumulated error in SVG rounding
  - #3321, Fix performance regression in topology loading
  - #3329, Fix robustness regression in TopoGeo_addPoint
  - #3349, Fix installation path of postgis_topology scripts
  - #3351, set endnodes isolation on ST_RemoveIsoEdge
    (and lwt_RemIsoEdge)
  - #3355, geography ST_Segmentize has geometry bbox
  - #3359, Fix toTopoGeom loss of low-id primitives from
    TopoGeometry definition
  - #3360, _raster_constraint_info_scale invalid input syntax
  - #3375, crash in repeated point removal for collection(point)
  - #3378, Fix handling of hierarchical TopoGeometries
    in presence of multiple topologies
  - #3380, #3402, Decimate lines on topology load
  - #3388, #3410, Fix missing end-points in ST_Removepoints
  - #3389, Buffer overflow in lwgeom_to_geojson
  - #3390, Compilation under Alpine Linux 3.2
    gives an error when compiling the postgis and postgis_topology extension
  - #3393, ST_Area NaN for some polygons
  - #3401, Improve ST_Split robustness on 32bit systems
  - #3404, ST_ClusterWithin crashes backend
  - #3407, Fix crash on splitting a face or an edge
    defining multiple TopoGeometry objects
  - #3411, Clustering functions not using spatial index
  - #3412, Improve robustness of snapping step in TopoGeo_addLinestring
  - #3415, Fix OSX 10.9 build under pkgsrc
  - Fix memory leak in lwt_ChangeEdgeGeom [liblwgeom]
  - PostGIS 2.2.0 2015/10/07
  * Important / Breaking Changes *
  - PROJ4 4.6 and higher only
  - #2703, KNN <-> operator now returns the correct distance ordering
    for all geometry types, not just for points. Code that expects
    the looser "centroid distance" ordering should be updated.
  - #3022, ValidateTopology swapped meaning of id1 and id2 for the
    'edge crosses node' error (now edge_id,node_id)
  - #2565, ST_SummaryStats(tablename, rastercolumn, ...) uses
    ST_SummaryStatsAgg()
  - #2567, ST_Count(tablename, rastercolumn, ...) uses ST_CountAgg()
  - #2842, raster - Hide unselectable tables from raster_overview
    and raster_columns
  - By default, PostGIS raster disables all GDAL drivers affecting
    out-db rasters, ST_FromGDALRaster() and ST_AsGDALRaster() variants
  - #3181, POINT EMPTY is now stored as POINT(NaN NaN) in WKB, instead of as MULTIPOINT EMPTY
  - Java binding moved to separate repository:
    https://github.com/postgis/postgis-java
  * Deprecated signatures *
  - #2748, ST_Shift_Longitude renamed to ST_ShiftLongitude,
    ST_Find_Extent renamed to ST_FindExtent,
    ST_Combine_BBox renamed to ST_CombineBbox,
    ST_Length_Spheroid renamed to ST_LengthSpheroid,
    ST_Distance_Spheroid renamed to ST_DistanceSpheroid,
    ST_Distance_Sphere renamed to ST_DistanceSphere,
    ST_3DLength_Spheroid deprecated (use ST_LengthSpheroid)
  - #2769, ST_Mem_Size renamed to ST_MemSize
  - #2565, ST_SummaryStats(tablename, rastercolumn, ...)
  - #2567, ST_Count(tablename, rastercolumn, ...)
  * New Features *
  - Topology API in liblwgeom
    (Sandro Santilli / Regione Toscana - SITA)
  - New lwgeom_version method in liblwgeom
  - New lwgeom_unaryunion method in liblwgeom
  - New lwgeom_linemerge method in liblwgeom
  - New lwgeom_is_simple method in liblwgeom
  - #3117, Add SFCGAL 1.1 support: add ST_3DDifference, ST_3DUnion,
    ST_Volume, ST_MakeSolid, ST_IsSolid (Vincent Mora / Oslandia)
  - #3169, ST_ApproximateMedialAxis (Sandro Santilli)
  - ST_CPAWithin (Sandro Santilli / Boundless)
  - Add |=| operator with CPA semantic and KNN support with PgSQL 9.5+
    (Sandro Santilli / Boundless)
  - #3131, KNN support for the geography type (Paul Ramsey / CartoDB)
  - #3023, ST_ClusterIntersecting / ST_ClusterWithin (Dan Baston)
  - #2703, Exact KNN results for all geometry types, aka "KNN re-check" (Paul Ramsey / CartoDB)
  - #1137, Allow a tolerance value in ST_RemoveRepeatedPoints (Paul Ramsey / CartoDB)
  - #3062, Allow passing M factor to ST_Scale (Sandro Santilli / Boundless)
  - #3139, ST_BoundingDiagonal (Sandro Santilli / Boundless)
  - #3129, ST_IsValidTrajectory (Sandro Santilli / Boundless)
  - #3128, ST_ClosestPointOfApproach (Sandro Santilli / Boundless)
  - #3152, ST_DistanceCPA (Sandro Santilli / Boundless)
  - Canonical output for index key types
  - ST_SwapOrdinates (Sandro Santilli / Boundless)
  - #2918, Use GeographicLib functions for geodetics (Mike Toews)
  - #3074, ST_Subdivide to break up large geometry (Paul Ramsey / CartoDB)
  - #3040, KNN GiST index based centroid (<<->>)
    n-D distance operators (Sandro Santilli / Boundless)
  - Interruptibility API for liblwgeom (Sandro Santilli / CartoDB)
  - #2939, ST_ClipByBox2D (Sandro Santilli / CartoDB)
  - #2247, ST_Retile and ST_CreateOverview: in-db raster overviews creation
    (Sandro Santilli / Vizzuality)
  - #899, -m shp2pgsql attribute names mapping -m switch
    (Regina Obe / Sandro Santilli)
  - #1678, Added GUC postgis.gdal_datapath to specify GDAL config
    variable GDAL_DATA
  - #2843, Support reprojection on raster import
    (Sandro Santilli / Vizzuality)
  - #2349, Support for encoded_polyline input/output (Kashif Rasul)
  - #2159, report libjson version from postgis_full_version()
  - #2770, ST_MemSize(raster)
  - #2093, ST_Simplify(geom, tol, preserveCollapsed) new parameter
  - Add postgis_noop(raster)
  - Added missing variants of ST_TPI(), ST_TRI() and ST_Roughness()
  - Added GUC postgis.gdal_enabled_drivers to specify GDAL config
    variable GDAL_SKIP
  - Added GUC postgis.enable_outdb_rasters to enable access to
    rasters with out-db bands
  - #2387, address_standardizer extension as part of PostGIS
    Stephen Woodbridge (imaptools.com), Walter Sinclair, Regina Obe
  - #2816, address_standardizer_data_us extension
    provides reference lex,gaz,rules for address_standardizer
    Stephen Woodbridge (imaptools.com), Walter Sinclair, Regina Obe
  - #2341, New mask parameter for ST_MapAlgebra
  - #2397, read encoding info automatically in shapefile loader
  - #2430, ST_ForceCurve
  - #2565, ST_SummaryStatsAgg()
  - #2567, ST_CountAgg()
  - #2632, ST_AsGML() support for curved features
  - #2652, Add --upgrade-path switch to run_test.pl
  - #2754, sfcgal wrapped as an extension
  - #2227, Simplification with Visvalingam-Whyatt algorithm
    ST_SimplifyVW, ST_SetEffectiveArea (Nicklas AvÃ©n)
  - Functions to encode and decode TWKB
    ST_AsTWKB, ST_GeomFromTWKB (Paul Ramsey / Nicklas AvÃ©n / CartoDB)
  * Enhancements *
  - #3223, Add memcmp short-circuit to ST_Equals (Daniel Baston)
  - #3227, Tiger geocoder upgraded to support Tiger 2015 census
  - #2278, Make liblwgeom potentially ABI-compatible between micro releases
  - #897, ST_AsX3D support for GeoCoordinates and systems "GD" "WE"
    ability to flip x/y axis (use option = 2, 3)
  - ST_Split: allow splitting lines by multilines, multipoints
    and (multi)polygon boundaries
  - #3070, Simplify geometry type constraint
  - #2839, Implement selectivity estimator for functional indexes,
    speeding up spatial queries on raster tables.
    (Sandro Santilli / Vizzuality)
  - #2361, Added spatial_index column to raster_columns view
  - #2390, Testsuite for pgsql2shp
  - #2527, Added -k flag to raster2pgsql to skip checking that
    band is NODATA
  - #2616, Reduce text casts during topology building and export
  - #2717, support startpoint, endpoint, pointn, numpoints for compoundcurve
  - #2747, Add support for GDAL 2.0
  - #2754, SFCGAL can now be installed with CREATE EXTENSION
    Vincent Mora (Oslandia)
  - #2828, Convert ST_Envelope(raster) from SQL to C
  - #2829, Shortcut ST_Clip(raster) if geometry fully contains the raster
    and no NODATA specified
  - #2906, Update tiger geocoder to handle tiger 2014 data
  - #3048, Speed up geometry simplification (J.Santana @ CartoDB)
  - #3092, Slow performance of geometry_columns with many tables
  * Bug Fixes *
  - #2893, Allow interruptibility of ST_Segmentize(geometry)
    (Sandro Santilli / CartoDB)
  - #2540, Change GUC name for GDAL_DATA to postgis.gdal_datapath
  - #2777, Raster max extent constraint based upon envelope to behave
    like geometry extent
  - #2822, Use @ operator instead of ST_CoveredBy() for raster
    max extent constraint
  - #3018, GROUP BY geography sometimes returns duplicate rows
  - #3020, ST_AddBand out-db bug where height using width value
  - #3048, shp2pgsql - illegal number format when specific system locale set
  - #3061, Allow duplicate points in JSON, GML, GML ST_GeomFrom* functions
  - #3086, ST_DumpValues() crashes backend on cleanup with invalid
    band indexes
  * Code refactoring *
  - Split raster/rt_core/rt_api.c and raster/rt_pg/rt_pg.c files into
    smaller files for ease of long-term maintenance and development
  - #1220, lwerror and lwnotice function became internal to liblwgeom
* Wed Dec 16 2015 m407@mail.ru
- Fixed JSON-C capability
* Sat Sep 26 2015 tzotsos@opensuse.org
- updated to 2.1.8
  * Bug Fixes *
  - #3159, do not force a bbox cache on ST_Affine
  - #3018, GROUP BY geography sometimes returns duplicate rows
  - #3048, shp2pgsql - illegal number format when specific system locale set
  - #3094, Malformed GeoJSON inputs crash backend
  - #3104, st_asgml introduces random characters in ID field
  - #3155, Remove liblwgeom.h on make uninstall
  - #3177, gserialized_is_empty cannot handle nested empty cases
  - Fix crash in ST_LineLocatePoint
* Sat Sep 26 2015 tzotsos@opensuse.org
- Merged postgis2 and postgresql9x-postgis to old postgis repository
- Merged changes files
* Mon Mar 23 2015 darin@darins.net
- updated to 2.1.6
  * Enhancements *
  - #3000, Ensure edge splitting and healing algorithms use indexes
  - #3048, Speed up geometry simplification (J.Santana @ CartoDB)
  - #3050, Speep up geometry type reading (J.Santana @ CartoDB)
  * Bug Fixes *
  - #2941, allow geography columns with SRID other than 4326
  - #3069, small objects getting inappropriately fluffed up w/ boxes
  - #3068, Have postgis_typmod_dims return NULL for unconstrained dims
  - #3061, Allow duplicate points in JSON, GML, GML ST_GeomFrom* functions
  - #3058, Fix ND-GiST picksplit method to split on the best plane
  - #3052, Make operators <-> and <#> available for PostgreSQL < 9.1
  - #3045, Fix dimensionality confusion in &&& operator
  - #3016, Allow unregistering layers of corrupted topologies
  - #3015, Avoid exceptions from TopologySummary
  - #3020, ST_AddBand out-db bug where height using width value
  - #3031, Allow restore of Geometry(Point) tables dumped with empties in them
- build and install the 2.0 libs, required for upgrades
- package for liblwgeom
* Fri Mar 20 2015 darin@darins.net
- add provides
- fix %%prep for package %%name change
- add conflicts for old packages
* Fri Mar 20 2015 darin@darins.net
- Fix package %%name
* Mon Mar  2 2015 bruno@ioda-net.ch
- Upgraded to PostGIS 2.1.5 released 2014/12/18
  * Enhancements *
  - #2933, Speedup construction of large multi-geometry objects
  * Bug Fixes *
  - #2947, Fix memory leak in lwgeommakevalid for single-component collection input
  - #2949, Fix memory leak in lwgeom_mindistance2d for curve input
  - #2931, BOX representation is case sensitive
  - #2942, PostgreSQL 9.5 support
  - #2953, 2D stats not generated when Z/M values are extreme
  - #3009, Geography cast may effect underlying tuple
- Packaging :
  - fix gdal-devel & geos-devel BuildRequire name
  - spec-cleaner (date,space,order)
* Mon Sep 22 2014 nikolai@prokoschenko.de
- Upgraded to PostGIS 2.1.4 released 2014/09/10 to fix building with json-c
  * Enhancements *
  - #2745, Speedup ST_Simplify calls against points
  - #2747, Support for GDAL 2.0
  - #2749, Make rtpostgisupgrade20_21.sql ACID
  - #2811, Do not specify index names when loading shapefiles/rasters
  - #2829, Shortcut ST_Clip(raster) if geometry fully contains the raster and no NODATA specified
  - #2895, Raise cost of ST_ConvexHull(raster) to 300 for better query plans
  * Bug Fixes *
  - #2605, armel: _ST_Covers() returns true for point in hole
  - #2911, Fix output scale on ST_Rescale/ST_Resample/ST_Resize of rasters with scale 1/-1 and offset 0/0.
  - Fix crash in ST_Union(raster)
  - #2704, ST_GeomFromGML() does not work properly with array of gml:pos (Even Roualt)
  - #2708, updategeometrysrid doesn’t update srid check when schema not specified. Patch from Marc Jansen
  - #2720, lwpolyaddring should update maxrings after realloc
  - #2759, Fix postgis_restore.pl handling of multiline object comments embedding sql comments
  - #2774, fix undefined behavior in ptarraycalculategbox_geodetic
  - Fix potential memory fault in ST_MakeValid
  - #2784, Fix handling of bogus argument to —with-sfcgal
  - #2772, Premature memory free in RASTER_getBandPath (ST_BandPath)
  - #2755, Fix regressions tests against all versions of SFCGAL
  - #2775, lwlinefromlwmpoint leaks memory
  - #2802, ST_MapAlgebra checks for valid callback function return value
  - #2803, ST_MapAlgebra handles no userarg and STRICT callback function
  - #2834, ST_Estimated_Extent and mixedCase table names (regression bug)
  - #2845, Bad geometry created from ST_AddPoint
  - #2870, Binary insert into geography column results geometry being inserted
  - #2872, make install builds documentation (Greg Troxell)
  - #2819, find isfinite or replacement on Centos5 / Solaris
  - #2899, geocode limit 1 not returning best answer (tiger geocoder)
  - #2903, Unable to compile on FreeBSD
  - #2927 reverse_geocode not filling in direction prefix (tiger geocoder) get rid of deprecated ST_Line_Locate_Point called
- Removed fix-lwin_geojson-c.patch which is obsolete since 2.1.4 (http://trac.osgeo.org/postgis/changeset/12663)
* Thu May 29 2014 bruno@ioda-net.ch
- Remove sfcgal functionality for SLE until dependencies are fixed
* Wed May 28 2014 bruno@ioda-net.ch
- Upgrading to PostGIS 2.1.3 released 2014/05/13
  * Important / Breaking Changes  *
  - Add control of GDAL drivers with the environment variable
    POSTGIS_GDAL_ENABLED_DRIVERS. By default, all GDAL drivers are disabled
  - Add ability to disable out-db raster bands with the environment variable
    POSTGIS_ENABLE_OUTDB_RASTERS. By default, out-db raster bands are disabled
  * Bug Fixes *
  - #2697, invalid GeoJSON Polygon input crashes server process
  - #2700, Fix dumping of higher-dimension datasets with null rows
  - #2706, ST_DumpPoints of EMPTY geometries crashes server
- Packaging
  * This new build enables sfcgal library allowing 3D operations inside
  the database
  * Spec-clean applied to meet 2014 requirements & quality
  * Fix project url: postgis homepage is postgis.net
    (postgis.org is owned by refractions research)
  * *********** Update notice ************************
  To upgrade a postgis 2.0 or 2.1 database you have to run
  begin;
  ALTER EXTENSION postgis UPDATE TO '2.1.3';
  ALTER EXTENSION postgis_topology UPDATE TO '2.1.3';
  commit;
  * **********************************************
* Mon Apr  7 2014 bruno@ioda-net.ch
- Upgrading to PostGIS 2.1.2 released on 2014/03/31
  * Important Changes *
  * Bug Fixes *
  - #2666, Error out at configure time if no SQL preprocessor can be found
  - #2534, st_distance returning incorrect results for large geographies
  - #2539, Check for json-c/json.h presence/usability before json/json.h
  - #2543, invalid join selectivity error from simple query
  - #2546, GeoJSON with string coordinates parses incorrectly
  - #2547, Fix ST_Simplify(TopoGeometry) for hierarchical topogeoms
  - #2552, Fix NULL raster handling in ST_AsPNG, ST_AsTIFF and
    ST_AsJPEG
  - #2555, Fix parsing issue of range arguments of ST_Reclass
  - #2556, geography ST_Intersects results depending on insert order
  - #2580, Do not allow installing postgis twice in the same database
  - #2589, Remove use of unnecessary void pointers
  - #2607, Cannot open more than 1024 out-db files in one process
  - #2610, Ensure face splitting algorithm uses the edge index
  - #2615, EstimatedExtent (and hence, underlying stats) gathering wrong bbox
  - #2619, Empty rings array in GeoJSON polygon causes crash
  - #2634, regression in sphere distance code
  - #2638, Geography distance on M geometries sometimes wrong
  - #2648, #2653, Fix topology functions when "topology" is not in search_path
  - #2654, Drop deprecated calls from topology
  - #2655, Let users without topology privileges call postgis_full_version()
  - #2674, Fix missing operator = and hash_raster_ops opclass on raster
  - #2675, #2534, #2636, #2634, #2638, Geography distance issues with tree optimization
  * Enhancements *
  - #2494, avoid memcopy in GiST index (hayamiz)
  - #2560, soft upgrade: avoid drop/recreate of aggregates that hadn't changed
* Wed Jan 22 2014 bruno@ioda-net.ch
- Packaging :
  * define main_version var and use it for .so and directories
  * Remove obsolete patches
    COPYING-patch.diff fixed upstream
    fix-lwgeom_in_kml.patch fixed upstream
    postgis-2.0.1_old_header_fix.patch fixed upstream
  * New requirement : postgis 2.1 need at least postgresql 9.0
    Build & Requires for postgresql >= 9.1 (SLE_11_SP3)
  * postgis 2.1 breaks compatibility from 2.0x version
    We build & package previous 2.0.4 postgis and rtpostgis
    to allow upgrade with the alter extension.
    openSUSE limit : only possible with the same postgresql
    server version
  * missing sfcgal linking (to be done soon)
  * New Patch : for factory json-c 0.11 headers are located
    in usr/include/json-c : lwin_geojson should use pc config file
- Upgrading to PostGIS 2.1.1 released on 2013/11/08
  * Important Changes *
  - #2514, Change raster license from GPL v3+ to v2+, allowing
    distribution of PostGIS Extension as GPLv2.
  * Bug Fixes *
  - #2396, Make regression tests more endian-agnostic
  - #2434, Fix ST_Intersection(geog,geog) regression in rare cases
  - #2454, Fix behavior of ST_PixelAsXXX functions regarding
    exclude_nodata_value parameter
  - #2449, Fix potential infinite loop in index building
  - #2489, Fix upgrades from 2.0 leaving stale function signatures
  - #2493, Fix behavior of ST_DumpValues when passed an empty raster
  - #2502, Fix postgis_topology_scripts_installed() install schema
  - #2504, Fix segfault on bogus pgsql2shp call
  - #2512, Support for foreign tables and materialized views in
    raster_columns and raster_overviews
  - #2525, Fix handling of SRID in nested collections
  - #2528, Fix memory leak in ST_Split / lwline_split_by_line
  - #2532, Add missing raster/geometry commutator operators
  - #2533, Remove duplicated signatures
  * Enhancements *
  - #2463, support for exact length calculations on arc geometries
  - #2478, support for tiger 2013
  - #2527, Added -k flag to raster2pgsql to skip checking that
    band is NODATA
- Upgrading to PostGIS 2.1.0 released on 2013/08/17
  * Important / Breaking Changes  *
  - #1653, Removed srid parameter from ST_Resample(raster) and variants
    with reference raster no longer apply reference raster's SRID.
  - #1962 ST_Segmentize - As a result of
    the introduction of geography support, The construct:
    SELECT ST_Segmentize('LINESTRING(1 2, 3 4)',0.5);
    will result in ambiguous function error
  - #2026, ST_Union(raster) now unions all bands of all rasters
  - #2089, liblwgeom: lwgeom_set_handlers replaces lwgeom_init_allocators.
  - #2150, regular_blocking is no longer a constraint. column of same name
    in raster_columns now checks for existance of spatially_unique
    and coverage_tile constraints
  - ST_Intersects(raster, geometry) behaves in the same manner as
    ST_Intersects(geometry, raster).
  - point variant of ST_SetValue(raster) previously did not check SRID
    of input geometry and raster.
  - ST_Hillshade parameters azimuth and altitude are now in degrees
    instead of radians.
  - ST_Slope and ST_Aspect return pixel values in degrees instead of radians.
  * Deprecated signatures *
  - #2104, ST_World2RasterCoord, ST_World2RasterCoordX and
    ST_World2RasterCoordY renamed to ST_WorldToRasterCoord,
    ST_WorldToRasterCoordX and ST_WorldToRasterCoordY.
    ST_Raster2WorldCoord, ST_Raster2WorldCoordX and
    ST_Raster2WorldCoordY renamed to ST_RasterToWorldCoord,
    ST_RasterToWorldCoordX and ST_RasterToWorldCoordY
  - ST_Estimated_Extent renamed to ST_EstimatedExtent
  - ST_Line_Interpolate_Point renamed to ST_LineInterpolatePoint
  - ST_Line_Substring renamed to ST_LineSubstring
  - ST_Line_Locate_Point renamed to ST_LineLocatePoint
  - ST_Force_XXX renamed to ST_ForceXXX
  - ST_MapAlgebraFctNgb and 1 and 2 raster variants of ST_MapAlgebraFct.
    Use ST_MapAlgebra instead
  - 1 and 2 raster variants of ST_MapAlgebraExpr.
    Use expression variants of ST_MapAlgebra instead
  * New Features *
  - Refer to http://postgis.net/docs/manual-2.1/PostGIS_Special_Functions_Index.html#NewFunctions_2_1
  for complete list of new functions
  - #310, ST_DumpPoints converted to a C function (Nathan Wagner)
  - #739, UpdateRasterSRID()
  - #945, improved join selectivity, N-D selectivity calculations,
    user accessible selectivity and stats reader functions for
    testing (Paul Ramsey / OpenGeo)
  - toTopoGeom with TopoGeometry sink (Sandro Santilli / Vizzuality)
  - clearTopoGeom (Sandro Santilli / Vizzuality)
  - ST_Segmentize(geography) (Paul Ramsey / OpenGeo)
  - ST_DelaunayTriangles (Sandro Santilli / Vizzuality)
  - ST_NearestValue, ST_Neighborhood (Bborie Park / UC Davis)
  - ST_PixelAsPoint, ST_PixelAsPoints (Bborie Park / UC Davis)
  - ST_PixelAsCentroid, ST_PixelAsCentroids (Bborie Park / UC Davis)
  - ST_Raster2WorldCoord, ST_World2RasterCoord (Bborie Park / UC Davis)
  - Additional raster/raster spatial relationship functions
    (ST_Contains, ST_ContainsProperly, ST_Covers, ST_CoveredBy, ST_Disjoint,
    ST_Overlaps, ST_Touches, ST_Within, ST_DWithin, ST_DFullyWithin)
    (Bborie Park / UC Davis)
  - Added array variants of ST_SetValues() to set many pixel values of a band
    in one call (Bborie Park / UC Davis)
  - #1293, ST_Resize(raster) to resize rasters based upon width/height
  - #1627, package tiger_geocoder as a PostgreSQL extension
  - #1643, #2076, Upgrade tiger geocoder to support loading tiger 2011 and 2012
    (Regina Obe / Paragon Corporation) Funded by Hunter Systems Group
  - GEOMETRYCOLLECTION support for ST_MakeValid (Sandro Santilli / Vizzuality)
  - #1709, ST_NotSameAlignmentReason(raster, raster)
  - #1818, ST_GeomFromGeoHash and friends (Jason Smith (darkpanda))
  - #1856, reverse geocoder rating setting for prefer numbered highway name
  - ST_PixelOfValue (Bborie Park / UC Davis)
  - Casts to/from PostgreSQL geotypes (point/path/polygon).
  - Added geomval array variant of ST_SetValues() to set many pixel values of
    a band using a set of geometries and corresponding values in one call
    (Bborie Park / UC Davis)
  - ST_Tile(raster) to break up a raster into tiles (Bborie Park / UC Davis)
  - #1895, new r-tree node splitting algorithm (Alex Korotkov)
  - #2011, ST_DumpValues to output raster as array (Bborie Park / UC Davis)
  - #2018, ST_Distance support for CircularString, CurvePolygon, MultiCurve,
    MultiSurface, CompoundCurve
  - #2030, n-raster (and n-band) ST_MapAlgebra (Bborie Park / UC Davis)
  - #2193, Utilize PAGC parser as drop in replacement for tiger normalizer
    (Steve Woodbridge, Regina Obe)
  - #2210, ST_MinConvexHull(raster)
  - lwgeom_from_geojson in liblwgeom (Sandro Santilli / Vizzuality)
  - #1687, ST_Simplify for TopoGeometry (Sandro Santilli / Vizzuality)
  - #2228, TopoJSON output for TopoGeometry (Sandro Santilli / Vizzuality)
  - #2123, ST_FromGDALRaster
  - #613, ST_SetGeoReference with numerical parameters instead of text
  - #2276, ST_AddBand(raster) variant for out-db bands
  - #2280, ST_Summary(raster)
  - #2163, ST_TPI for raster (Nathaniel Clay)
  - #2164, ST_TRI for raster (Nathaniel Clay)
  - #2302, ST_Roughness for raster (Nathaniel Clay)
  - #2290, ST_ColorMap(raster) to generate RGBA bands
  - #2254, Add SFCGAL backend support.
    (Backend selection throught postgis.backend var)
    Functions available both throught GEOS or SFCGAL:
    ST_Intersects, ST_3DIntersects, ST_Intersection, ST_Area,
    ST_Distance, ST_3DDistance
    New functions available only with SFCGAL backend:
    ST_3DIntersection, ST_Tesselate, ST_3DArea, ST_Extrude, ST_ForceLHR
    ST_Orientation, ST_Minkowski, ST_StraightSkeleton
    postgis_sfcgal_version
    New function available in PostGIS: ST_ForceSFS
    (Olivier Courtin and Hugo Mercier / Oslandia)
  * Enhancements *
  - #823,  tiger geocoder: Make loader_generate_script download portion
    less greedy
  - #826,  raster2pgsql no longer defaults to padding tiles. Flag -P
    can be used to pad tiles
  - #1363, ST_AddBand(raster, ...) array version rewritten in C
  - #1364, ST_Union(raster, ...) aggregate function rewritten in C
  - #1655, Additional default values for parameters of ST_Slope
  - #1661, Add aggregate variant of ST_SameAlignment
  - #1719, Add support for Point and GeometryCollection ST_MakeValid inputs
  - #1780, support ST_GeoHash for geography
  - #1796, Big performance boost for distance calculations in geography
  - #1802, improved function interruptibility.
  - #1823, add parameter in ST_AsGML to use id column for GML 3 output
    (become mandatory since GML 3.2.1)
  - #1856, tiger geocoder: reverse geocoder rating setting for prefer
    numbered highway name
  - #1938, Refactor basic ST_AddBand to add multiple new bands in one call
  - #1978, wrong answer when calculating length of a closed circular
    arc (circle)
  - #1989, Preprocess input geometry to just intersection with raster
    to be clipped
  - #2021, Added multi-band support to ST_Union(raster, ...) aggregate function
  - #2006, better support of ST_Area(geography) over poles and dateline
  - #2065, ST_Clip(raster, ...) now a C function
  - #2069, Added parameters to ST_Tile(raster) to control padding of tiles
  - #2078, New variants of ST_Slope, ST_Aspect and ST_HillShade to provide
    solution to handling tiles in a coverage
  - #2097, Added RANGE uniontype option for ST_Union(raster)
  - #2105, Added ST_Transform(raster) variant for aligning output to
    reference raster
  - #2119, Rasters passed to ST_Resample(), ST_Rescale(), ST_Reskew(),
    and ST_SnapToGrid() no longer require an SRID
  - #2141, More verbose output when constraints fail to be added
    to a raster column
  - #2143, Changed blocksize constraint of raster to allow multiple values
  - #2148, Addition of coverage_tile constraint for raster
  - #2149, Addition of spatially_unique constraint for raster
  - TopologySummary output now includes unregistered layers and a count
    of missing TopoGeometry objects from their natural layer.
  - ST_HillShade(), ST_Aspect() and ST_Slope() have one new optional
    parameter to interpolate NODATA pixels before running the
    operation.
  - Point variant of ST_SetValue(raster) is now a wrapper around geomval
    variant of ST_SetValues(rast).
  - Proper support for raster band's isnodata flag in core API and loader.
  - Additional default values for parameters of ST_Aspect and ST_HillShade
  - #2178, ST_Summary now advertises presence of known srid with an [S] flag
  - #2202, Make libjson-c optional (--without-json configure switch)
  - #2213, Add support libjson-c 0.10+
  - #2231, raster2pgsql supports user naming of filename column with -n
  - #2200, ST_Union(raster, uniontype) unions all bands of all rasters
  - #2264, postgis_restore.pl support for restoring into databases
    with postgis in a custom schema
  - #2244, emit warning when changing raster's georeference if raster has
    out-db bands
  - #2222, add parameter OutAsIn to flag whether ST_AsBinary should
    return out-db bands as in-db bands
  * Fixes *
  - #1839, handling of subdatasets in GeoTIFF in raster2pgsql.
  - #1840, fix logic of when to compute # of tiles in raster2pgsql.
  - #1870, align the docs and actual behavior of raster's ST_Intersects
  - #1872, fix ST_ApproxSummarystats to prevent division by zero
  - #1875, ST_SummaryStats returns NULL for all parameters except count
    when count is zero
  - #1932, fix raster2pgsql of syntax for index tablespaces
  - #1936, ST_GeomFromGML on CurvePolygon causes server crash
  - #1939, remove custom data types: summarystats, histogram, quantile,
    valuecount
  - #1951, remove crash on zero-length linestrings
  - #1957, ST_Distance to a one-point LineString returns NULL
  - #1976, Geography point-in-ring code overhauled for more reliability
  - #1981, cleanup of unused variables causing warnings with gcc 4.6+
  - #1996, support POINT EMPTY in GeoJSON output
  - #2062, improve performance of distance calculations
  - #2057, Fixed linking issue for raster2psql to libpq
  - #2077, Fixed incorrect values returning from ST_Hillshade()
  - #2019, ST_FlipCoordinates does not update bbox
  - #2100, ST_AsRaster may not return raster with specified pixel type
  - #2126, Better handling of empty rasters from ST_ConvexHull()
  - #2165, ST_NumPoints regression failure with CircularString
  - #2168, ST_Distance is not always commutative
  - #2182, Fix issue with outdb rasters with no SRID and ST_Resize
  - #2188, Fix function parameter value overflow that caused problems
    when copying data from a GDAL dataset
  - #2198, Fix incorrect dimensions used when generating bands of out-db
    rasters in ST_Tile()
  - #2201, ST_GeoHash wrong on boundaries
  - #2203, Changed how rasters with unknown SRID and default geotransform
    are handled when passing to GDAL Warp API
  - #2215, Fixed raster exclusion constraint for conflicting name of
    implicit index
  - #2251, Fix bad dimensions when rescaling rasters with default
    geotransform matrix
  - #2133, Fix performance regression in expression variant of ST_MapAlgebra
  - #2257, GBOX variables not initialized when testing with empty geometries
  - #2271, Prevent parallel make of raster
  - #2282, Fix call to undefined function nd_stats_to_grid() in debug mode
  - #2307, ST_MakeValid outputs invalid geometries
  - #2309, Remove confusing INFO message when trying to get SRS info
  - #2336, FIPS 20 (KS) causes wildcard expansion to wget all files
  - #2348, Provide raster upgrade path for 2.0 to 2.1
  - #2351, st_distance between geographies wrong
  - #2359, Fix handling of schema name when adding overview constraints
  - #2371, Support GEOS versions with more than 1 digit in micro
  - #2383, Remove unsafe use of \' from raster warning message
  - #2384, Incorrect variable datatypes for ST_Neighborhood
  * Known Issues *
  - #2111, Raster bands can only reference the first 256 bands of out-db rasters
* Sun Sep 29 2013 bruno@ioda-net.ch
- Packaging : keep upstream tar format (.gz)
- Redone patch for lwgeom_kml against 2.0.4
- Removed merged upstream patches
    postgis-2.0.1_old_header_fix.patch
    COPYING-patch.diff
- Upgrading to upstream 2.0.4 bugfix release
    PostGIS 2.0.4 2013/09/06
  * Bug Fixes *
  - #2110, Equality operator between EMPTY and point on origin
  - Allow adding points at precision distance with TopoGeo_addPoint
  - #1968, Fix missing edge from toTopoGeom return
  - #2165, ST_NumPoints regression failure with CircularString
  - #2168, ST_Distance is not always commutative
  - #2186, gui progress bar updates too frequent
  - #2201, ST_GeoHash wrong on boundaries
  - #2257, GBOX variables not initialized when testing with empty geometries
  - #2271, Prevent parallel make of raster
  - #2267, Server crash from analyze table
  - #2277, potential segfault removed
  - #2307, ST_MakeValid outputs invalid geometries
  - #2351, st_distance between geographies wrong
  - #2359, Incorrect handling of schema for overview constraints
  - #2371, Support GEOS versions with more than 1 digit in micro
  - #2372, Cannot parse space-padded KML coordinates
  - Fix build with systemwide liblwgeom installed
  - #2383, Fix unsafe use of \' in warning message
  - #2410, Fix segmentize of collinear curve
  - #2415, ST_Multi support for COMPOUNDCURVE and CURVEPOLYGON
  - #2412, ST_LineToCurve support for lines with less than 4 vertices
  - #2420, ST_LineToCurve: require at least 8 edges to define a full circle
  - #2423, ST_LineToCurve: require all arc edges to form the same angle
  - #2424, ST_CurveToLine: add support for COMPOUNDCURVE in MULTICURVE
  - #2427, Make sure to retain first point of curves on ST_CurveToLine
  * Enhancements *
  - #2269, Avoid uselessly de-toasting full geometries on ANALYZE
  * Known Issues *
  - #2111, Raster bands can only reference the first 256 bands of out-db rasters
* Sat Mar  2 2013 bruno@ioda-net.ch
- Packaging : make postgis2 building and available on 12.1,12.2,12.3
  with new way of packaging postgresql (/usr/lib/postgresqlXX)
- Added patch for fsf
- Upgrading to last bug fixes release 2.0.3
  * Bug Fixes *
  - #2126, Better handling of empty rasters from ST_ConvexHull()
  - #2134, Make sure to process SRS before passing it off to GDAL functions
  - Fix various memory leaks in liblwgeom
  - #2173, Fix robustness issue in splitting a line with own vertex
    also affecting topology building (#2172)
  - #2174, Fix usage of wrong function lwpoly_free()
  - #2176, Fix robustness issue with ST_ChangeEdgeGeom
  - #2184, Properly copy topologies with Z value
  - postgis_restore.pl support for mixed case geometry column name in dumps
  - #2188, Fix function parameter value overflow that caused problems
    when copying data from a GDAL dataset
  - #2216, More memory errors in MultiPolygon GeoJSON parsing (with holes)
  - Fix Memory leak in GeoJSON parser
  * Enhancements *
  - #2141, More verbose output when constraints fail to be added
    to a raster column
  - Speedup ST_ChangeEdgeGeom
  PostGIS 2.0.2 related
  * Bug Fixes *
  - #1287, Drop of "gist_geometry_ops" broke a few clients
    package of legacy_gist.sql for these cases
  - #1391, Errors during upgrade from 1.5
  - #1828, Poor selectivity estimate on ST_DWithin
  - #1838, error importing tiger/line data
  - #1869, ST_AsBinary is not unique -
    added to legacy_minor/legacy.sql scripts
  - #1885, Missing field from tabblock table in tiger2010 census_loader.sql
  - #1891, Use LDFLAGS environment when building liblwgeom
  - #1899, Enhance toTopoGeom error on unsupported input
  - #1900, Fix pgsql2shp for big-endian systems
  - #1932, Fix raster2pgsql for invalid syntax for setting index tablespace
  - #1936, ST_GeomFromGML on CurvePolygon causes server crash
  - #1955, ST_ModEdgeHeal and ST_NewEdgeHeal for doubly connected edges
  - #1957, ST_Distance to a one-point LineString returns NULL
  - #1976, Geography point-in-ring code overhauled for more reliability
  - #1978, wrong answer calculating length of closed circular arc (circle)
  - #1981, Remove unused but set variables as found with gcc 4.6+
  - #1987, Restore 1.5.x behaviour of ST_Simplify
  - #1989, Preprocess input geometry to just intersection with raster
    to be clipped
  - #1991, geocode really slow on PostgreSQL 9.2
  - #1996, support POINT EMPTY in GeoJSON output
  - #1998, Fix ST_{Mod,New}EdgeHeal joining edges sharing both endpoints
  - #2001, ST_CurveToLine has no effect if the geometry doesn't actually
    contain an arc
  - #2015, ST_IsEmpty('POLYGON(EMPTY)') returns False
  - #2019, ST_FlipCoordinates does not update bbox
  - #2025, Fix side location conflict at TopoGeo_AddLineString
  - #2062, improve performance of distance calculations
  - #2033, Fix adding a splitting point into a 2.5d topology
  - #2051, Fix excess of precision in ST_AsGeoJSON output
  - #2052, Fix buffer overflow in lwgeom_to_geojson
  - #2056, Fixed lack of SRID check of raster and geometry in ST_SetValue()
  - #2057, Fixed linking issue for raster2psql to libpq
  - #2060, Fix "dimension" check violation by GetTopoGeomElementArray
  - #2072, Removed outdated checks preventing ST_Intersects(raster) from
    working on out-db bands
  - #2077, Fixed incorrect answers from ST_Hillshade(raster)
  - #2092, Namespace issue with ST_GeomFromKML,ST_GeomFromGML for libxml 2.8+
  - #2099, Fix double free on exception in ST_OffsetCurve
  - #2100, ST_AsRaster() may not return raster with specified pixel type
  - #2108, Ensure ST_Line_Interpolate_Point always returns POINT
  - #2109, Ensure ST_Centroid always returns POINT
  - #2117, Ensure ST_PointOnSurface always returns POINT
  - #2129, Fix SRID in ST_Homogenize output with collection input
  - #2130, Fix memory error in MultiPolygon GeoJson parsing
  - Update URL of Maven jar
  * Enhancements *
  - #1581, ST_Clip(raster, ...) no longer imposes NODATA on a band if the
    corresponding band from the source raster did not have NODATA
  - #1928, Accept array properties in GML input multi-geom input
    (Kashif Rasul and Shoaib Burq / SpacialDB)
  - #2082, Add indices on start_node and end_node of topology edge tables
  - #2087, Speedup topology.GetRingEdges using a recursive CTE
* Tue Feb 26 2013 bruno@ioda-net.ch
- Handle correctly build for 11.4 & SLE (old way for postgresql)
- Add filter about exit + explanation
* Wed Feb 13 2013 bruno@ioda-net.ch
- Upgrade to 1.5.8 version compatible with postgresql 9.2
  Release Note:
  This is a bug fix release, addressing issues that have been filed since
  the 1.5.6 release. To go with the GEO 3.3.6 release, and to celebrate
  PostGIS day (and to get rid of an issue with wrong answers returned by
  ST_Within() and ST_CoveredBy())
  Bug Fixed 1.5.8, 1.5.7
    [#2048], ST_Within and ST_CoveredBy producing bad results
    [#2095], proj4 cache corrupted by projection error
  [#2071], Add PgSQL 9.2 support updates to 1.5.6
* Tue Dec  4 2012 tzotsos@opensuse.org
- Moved SQL scripts to /usr/share/postgresql91/extension
* Fri Nov 30 2012 tzotsos@opensuse.org
- Bug #786288 fixed
* Fri Jun 22 2012 tzotsos@opensuse.org
- Updating to 2.0.1:
  * Bug Fixes *
  - #1264, fix st_dwithin(geog, geog, 0).
  - #1468  shp2pgsql-gui table column schema get shifted
  - #1694, fix building with clang. (vince)
  - #1708, improve restore of pre-PostGIS 2.0 backups.
  - #1714, more robust handling of high topology tolerance.
  - #1755, ST_GeographyFromText support for higher dimensions.
  - #1759, loading transformed shapefiles in raster enabled db.
  - #1761, handling of subdatasets in NetCDF, HDF4 and HDF5 in raster2pgsql.
  - #1763, topology.toTopoGeom use with custom search_path.
  - #1766, don't let ST_RemEdge* destroy peripheral TopoGeometry objects.
  - #1774, Clearer error on setting an edge geometry to an invalid one.
  - #1775, ST_ChangeEdgeGeom collision detection with 2-vertex target.
  - #1776, fix ST_SymDifference(empty, geom) to return geom.
  - #1779, install SQL comment files.
  - #1782, fix spatial reference string handling in raster.
  - #1789, fix false edge-node crossing report in ValidateTopology.
  - #1790, fix toTopoGeom handling of duplicated primitives.
  - #1791, fix ST_Azimuth with very close but distinct points.
  - #1797, fix (ValidateTopology(xxx)).* syntax calls.
  - #1805, put back the 900913 SRID entry.
  - #1813, Only show readable relations in metadata tables.
  - #1819, fix floating point issues with ST_World2RasterCoord and
    ST_Raster2WorldCoord variants.
  - #1820  compilation on 9.2beta1.
  - #1822, topology load on PostgreSQL 9.2beta1.
  - #1825, fix prepared geometry cache lookup
  - #1829, fix uninitialized read in GeoJSON parser
  - #1834, revise postgis extension to only backup
    user specified spatial_ref_sys
  - #1839, handling of subdatasets in GeoTIFF in raster2pgsql.
  - #1840, fix logic of when to compute # of tiles in raster2pgsql.
  - #1851, fix spatial_ref_system parameters for EPSG:3844
  - #1857, fix failure to detect endpoint mismatch in ST_AddEdge*Face*
  - #1865, data loss in postgis_restore.pl when data rows have leading
    dashes.
  - #1867, catch invalid topology name passed to topogeo_add*
  - #1870, align the docs and actual behavior of raster's ST_Intersects
  - #1872, fix ST_ApproxSummarystats to prevent division by zero
  - #1873, fix ptarray_locate_point to return interpolated Z/M values for
    on-the-line case
  - #1875, ST_SummaryStats returns NULL for all parameters except count
    when count is zero
  * Enhancements *
  - More detailed exception message from topology editing functions.
  - #1786, improved build dependencies
  - #1806, speedup of ST_BuildArea, ST_MakeValid and ST_GetFaceGeometry.
  - #1812, Add lwgeom_normalize in LIBLWGEOM for more stable testing.
* Sun May  6 2012 dassau@gbd-consult.de
- update to version 1.5.4
- Bug Fixes
  - #547, ST_Contains memory problems (Sandro Santilli)
  - #621, Problem finding intersections with geography (Paul Ramsey)
  - #627, PostGIS/PostgreSQL process die on invalid geometry (Paul Ramsey)
  - #810, Increase accuracy of area calculation (Paul Ramsey)
  - #852, improve spatial predicates robustness (Sandro Santilli, Nicklas Avén)
  - #877, ST_Estimated_Extent returns NULL on empty tables (Sandro Santilli)
  - #1028, ST_AsSVG kills whole postgres server when fails (Paul Ramsey)
  - #1056, Fix boxes of arcs and circle stroking code (Paul Ramsey)
  - #1135, improve testsuite predictability (Andreas 'ads' Scherbaum)
  - #1146, images generator crashes (bronaugh)
  - #1170, North Pole intersection fails (Paul Ramsey)
  - #1179, ST_AsText crash with bad value (kjurka)
  - #1184, honour DESTDIR in documentation Makefile (Bryce L Nordgren)
  - #1227, server crash on invalid GML
  - #1252, SRID appearing in WKT (Paul Ramsey)
  - #1264, st_dwithin(g, g, 0) doesn't work (Paul Ramsey)
  - #1344, allow exporting tables with invalid geometries (Sandro Santilli)
  - #1389, wrong proj4text for SRID 31300 and 31370 (Paul Ramsey)
  - #1406, shp2pgsql crashes when loading into geography (Sandro Santilli)
  - #1595, fixed SRID redundancy in ST_Line_SubString (Sandro Santilli)
  - #1596, check SRID in UpdateGeometrySRID (Mike Toews, Sandro Santilli)
  - #1602, fix ST_Polygonize to retain Z (Sandro Santilli)
  - #1697, fix crash with EMPTY entries in GiST index (Paul Ramsey)
  - #1772, fix ST_Line_Locate_Point with collapsed input (Sandro Santilli)
  - #1799, Protect ST_Segmentize from max_length=0  (Sandro Santilli)
  - Alter parameter order in 900913 (Paul Ramsey)
  - Support builds with "gmake" (Greg Troxel)
* Sat Apr 21 2012 tzotsos@opensuse.org
- Added shp2pgsql utility (#757090).
* Sat Apr 21 2012 tzotsos@opensuse.org
- Enabled build with topology (#757094).
* Tue Apr  3 2012 tzotsos@opensuse.org
- Updating to 2.0.0 Gold:
  * Raster data and raster/vector analysis in the database
  * Topological models to handle objects with shared boundaries
  * PostgreSQL typmod integration, for an automagical
  geometry_columns table
  * 3D and 4D indexing
  * Index-based high performance nearest-neighbour searching
  * Many more vector functions including
  * ST_Split
  * ST_Node
  * ST_MakeValid
  * ST_OffsetCurve
  * ST_ConcaveHull
  * ST_AsX3D
  * ST_GeomFromGeoJSON
  * ST_3DDistance
  * Integration with the PostgreSQL 9.1 extension system
  * Improved commandline shapefile loader/dumper
  * Multi-file import support in the shapefile GUI
  * Multi-table export support in the shapefile GUI
  * A geo-coder optimized for free US Census
  TIGER (2010) data
* Thu Dec  8 2011 otto.dassau@gmx.de
- fixed double packaged files
- fixed directory /usr/lib/postgresql not owned by a package
* Sat Oct  8 2011 bruno@ioda-net.ch
- Update to current version 1.5.3
- Corrected Groups affectation
- Patch FSF address
- use %%__make %%{?_smp_mflags};
- Refresh description which was outdated (1.3x)
- Fixed url to point now to www.postgis.org
* Wed Aug 17 2011 idonmez@novell.com
- Add a changes file, fix proj dependency
* Tue Nov  2 2010 dassau@gbd-consult.de
- update to current version
  Fri Mar 19 00:00:00 UTC 2010 - Otto Dassau 1.5.1
- update to current version
  Fri Feb 19 00:00:00 UTC 2010 - Otto Dassau 1.5.0
- update to current version
- remove fixwarnings.diff patch
- added doc/postgis_comment.sql
  Thu Dec 31 00:00:00 UTC 2009 - Otto Dassau 1.4.1
- update to current version
  Fri Sep  4 00:00:00 UTC 2009 - Otto Dassau 1.4.0
- update to current version
- sqldir is now /usr/share/postgresql/contrib
  Wed Jan 28 00:00:00 UTC 2009 - Otto Dassau 1.3.5
- update to current version
  Tue Nov 25 00:00:00 UTC 2008 - Otto Dassau 1.3.4
- update to current version
  Mon Jul 14 00:00:00 UTC 2008 - Otto Dassau 1.3.3
- added rpmlintrc file
* Mon Jul  9 2007 opensuse@dstoecker.de
- adapted to openSUSE build service
  Thu Dec 22 00:00:00 UTC 2005 - Devrim GUNDUZ 1.1.0
- Final fixes for 1.1.0
  Tue Dec  6 00:00:00 UTC 2005 - Devrim GUNDUZ 1.10
- Update to 1.1.0
  Mon Oct  3 00:00:00 UTC 2005 - Devrim GUNDUZ
- Make PostGIS build against pgxs so that we don't need PostgreSQL sources.
- Fixed all build errors except jdbc (so, defaulted to 0)
- Added new files under utils
- Removed postgis-jdbc2-makefile.patch (applied to -head)
  Tue Sep 27 00:00:00 UTC 2005 - Devrim GUNDUZ 1.0.4
- Update to 1.0.4
  Wed Apr 20 00:00:00 UTC 2005 - Devrim GUNDUZ 1.0.0
- 1.0.0 Gold
  Sun Apr 17 00:00:00 UTC 2005 - Devrim GUNDUZ
- Modified the spec file so that we can build JDBC2 RPMs...
- Added -utils RPM to package list.
  Fri Apr 15 00:00:00 UTC 2005 - Devrim GUNDUZ
- Added preun and postun scripts.
  Sat Apr  9 00:00:00 UTC 2005 - Devrim GUNDUZ
- Initial RPM build
- Fixed libdir so that PostgreSQL installations will not complain about it.
- Enabled --with-geos and modified the old spec.
